 
      PROGRAM MOMINERT
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c MomInert: a code for moments of inertia.
c Copyright (C) 2003 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful,
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
C     Designed to calculated moments of inertia for internal rotations.
C     These can either be connected to a larger mass object or stand-alone.
C
C     Input File Specifications:
C
C     1. Title
C             A line, up to 100 characters, describing the data.  This title is
C        reproduced in the output file.
C
C     2. Total number of atoms in the molecule, NATOMS.
C
C     3. Atom type, Atom index, X-coordinate, Y-coordinate, Z-coordinate
C        Atom type: Character*2, case sensitive atomic symbol, eg C, Br
C        Atom index: Identification number of the atom (1 to NATOMS)
C        X-coordinate, Y-coordinate, Z-coordinate in angstroms
C
C        Repeat for every atom.
C
C     4. Atom indices for the two atoms defining the axis of rotation. If the
C       atom indices are set equal to zero, then internal rotor is not calculated
C       and lines #5 and #6 can be omitted.
C
C     5. Number of atoms in one of the rotating moieties.
C
C     6. List of the atoms in that moiety.
C
C
C     Cartesian coordinates are in Angstroms, and the moments of inertia
C     are reported in amu*Ang*Ang.
 
      IMPLICIT NONE
 
      CHARACTER AVERSION*6, ADATE*12
      PARAMETER (AVERSION='1.4.1 ', ADATE='SEP 2004  ' )

      INTEGER NATOMS , I , J , K , ROT1 , ROT2 , NUMROT , ROTING1(100)
      INTEGER ROTING2(100) , NUMROT2 , MOL , ATOM3 , N , NP , ierr , IV
      CHARACTER*6 ATYPE(100) , AT
      CHARACTER*100 TITLE
      DOUBLE PRECISION XCOORD(100) , YCOORD(100) , ZCOORD(100) , X1 , 
     &                 X2 , X3
      DOUBLE PRECISION Y1 , Y2 , Y3 , Z1 , Z2 , Z3 , R(100) , A1 , A2 , 
     &                 C1 , C2
      DOUBLE PRECISION D1 , D2 , A , C , DIST1(100) , DIST2(100) , X , 
     &                 Y , Z
      DOUBLE PRECISION MASS(100) , MOMENT1 , MOMENT2 , REDMOM , XC , 
     &                 YC , ZC
      DOUBLE PRECISION TOTMASS , XCM , YCM , ZCM , XPRIME(100) , 
     &                 YPRIME(100)
      DOUBLE PRECISION ZPRIME(100) , IXX , IYY , IZZ , IYZ , IXY , IXZ
      DOUBLE PRECISION MAT(3,3) , EIG(3) , fv1(3) , fv2(3) , ZZ(3,3)
      DOUBLE PRECISION TEST12 , TEST13 , TESTZ12 , TESTZ13 , CONV
 
C     MAC: The ouput file, designated 'MomInert.OUT' is created as a Tex-Edit
C     Plus file.  The input file is user-designated, and can be any text-
C     based file.
 
cMAC      OPEN(UNIT=4,FILE='mominert.out',CREATOR='TBB6',STATUS='UNKNOWN')
cMAC      OPEN(UNIT=2,FILE='',STATUS='OLD')
      OPEN (UNIT=4,FILE='mominert.out',STATUS='UNKNOWN')
      OPEN (UNIT=2,FILE='mominert.dat',STATUS='OLD')
 
      READ (2,99001) TITLE
      READ (2,*) NATOMS
 
      WRITE (4,99002) AVERSION , ADATE
      WRITE (4,*) TITLE
      WRITE (4,*)
      WRITE (4,99003) 'NUMBER' , 'TYPE  ' , 'X' , 'Y' , 'Z'
 
C     Here zero all arrays to avoid external interference with calculations.
 
      DO 100 I = 1 , 100
         DIST1(I) = 0.D+00
         DIST2(I) = 0.D+00
         XCOORD(I) = 0.D+00
         YCOORD(I) = 0.D+00
         ZCOORD(I) = 0.D+00
         R(I) = 0.D+00
         ROTING1(I) = 0
         ROTING2(I) = 0
 100  CONTINUE
 
      DO 200 I = 1 , NATOMS
         READ (2,*) AT , MOL , XC , YC , ZC
         ATYPE(MOL) = AT
         XCOORD(MOL) = XC
         YCOORD(MOL) = YC
         ZCOORD(MOL) = ZC
 200  CONTINUE
 
      DO 300 I = 1 , NATOMS
         WRITE (4,99004) I , ATYPE(I) , XCOORD(I) , YCOORD(I) , 
     &                   ZCOORD(I)
 300  CONTINUE
 
C     Define the mass of each atom.
C     This is done with simple character recognition, and the masses are
C     given in terms of amu.
 
      DO 400 I = 1 , NATOMS
         IF ( ATYPE(I).EQ.'C' ) THEN
            MASS(I) = 12.011D+00
         ELSEIF ( ATYPE(I).EQ.'C12' ) THEN
            MASS(I) = 12.0D+00
         ELSEIF ( ATYPE(I).EQ.'C13' ) THEN
            MASS(I) = 13.0D+00
         ELSEIF ( ATYPE(I).EQ.'C14' ) THEN
            MASS(I) = 14.0D+00
         ELSEIF ( ATYPE(I).EQ.'Si' ) THEN
            MASS(I) = 28.09D+00
         ELSEIF ( ATYPE(I).EQ.'Si29' ) THEN
            MASS(I) = 28.98D+00
         ELSEIF ( ATYPE(I).EQ.'Si30' ) THEN
            MASS(I) = 29.97D+00
         ELSEIF ( ATYPE(I).EQ.'H' ) THEN
            MASS(I) = 1.0079D+00
         ELSEIF ( ATYPE(I).EQ.'D' ) THEN
            MASS(I) = 2.0D+00
         ELSEIF ( ATYPE(I).EQ.'T' ) THEN
            MASS(I) = 3.0D+00
         ELSEIF ( ATYPE(I).EQ.'O' ) THEN
            MASS(I) = 15.9994D+00
         ELSEIF ( ATYPE(I).EQ.'O17' ) THEN
            MASS(I) = 17.0D+00
         ELSEIF ( ATYPE(I).EQ.'O18' ) THEN
            MASS(I) = 18.0D+00
         ELSEIF ( ATYPE(I).EQ.'S' ) THEN
            MASS(I) = 32.06D+00
         ELSEIF ( ATYPE(I).EQ.'S34' ) THEN
            MASS(I) = 34.0D+00
         ELSEIF ( ATYPE(I).EQ.'N' ) THEN
            MASS(I) = 14.0067D+00
         ELSEIF ( ATYPE(I).EQ.'N15' ) THEN
            MASS(I) = 15.0D+00
         ELSEIF ( ATYPE(I).EQ.'P' ) THEN
            MASS(I) = 30.97D+00
         ELSEIF ( ATYPE(I).EQ.'F' ) THEN
            MASS(I) = 18.9984D+00
         ELSEIF ( ATYPE(I).EQ.'Cl' ) THEN
            MASS(I) = 35.453D+00
         ELSEIF ( ATYPE(I).EQ.'Cl35' ) THEN
            MASS(I) = 35.0D+00
         ELSEIF ( ATYPE(I).EQ.'Cl37' ) THEN
            MASS(I) = 37.0D+00
         ELSEIF ( ATYPE(I).EQ.'Br' ) THEN
            MASS(I) = 79.904D+00
         ELSEIF ( ATYPE(I).EQ.'Br79' ) THEN
            MASS(I) = 79.0D+00
         ELSEIF ( ATYPE(I).EQ.'Br81' ) THEN
            MASS(I) = 81.0D+00
         ELSEIF ( ATYPE(I).EQ.'I ' ) THEN
            MASS(I) = 126.905D+00
         ELSEIF ( ATYPE(I).EQ.'Ne' ) THEN
            MASS(I) = 20.18D+00
         ELSEIF ( ATYPE(I).EQ.'Ar' ) THEN
            MASS(I) = 39.948D+00
         ELSEIF ( ATYPE(I).EQ.'Kr' ) THEN
            MASS(I) = 83.8D+00
         ELSEIF ( ATYPE(I).EQ.'Xe' ) THEN
            MASS(I) = 131.3D+00
         ENDIF
 400  CONTINUE
 
C     Read atoms which define rotation axis and report them to user.
 
      WRITE (4,*)
      READ (2,*) ROT1 , ROT2
      IF ( ROT1.NE.0 ) THEN
         WRITE (4,99005) 'ATOMS' , ROT1 , 'AND' , ROT2 , 
     &                   'DEFINE ROTATION AXIS'
         READ (2,*) NUMROT
 
C     Read atoms which make up the first rotating moiety and report them.
C     Reporting allows for ease in finding mistakes.
 
         WRITE (4,*)
         READ (2,*) (ROTING1(I),I=1,NUMROT)
         WRITE (4,*) '  MOIETY 1 CONTAINS ATOMS:' , 
     &               (ROTING1(I),I=1,NUMROT)
 
         WRITE (4,*)
 
C     All atoms which are not in the first moiety must be in the second
C     moiety.  Define it here.
 
         NUMROT2 = NATOMS - NUMROT
         K = 1
         DO 450 I = 1 , NATOMS
            DO 420 J = 1 , NUMROT
               IF ( I.EQ.ROTING1(J) ) GOTO 450
 420        CONTINUE
            ROTING2(K) = I
            K = K + 1
 450     CONTINUE
         WRITE (4,*) '  MOIETY 2 CONTAINS ATOMS:' , 
     &               (ROTING2(I),I=1,NUMROT2)
 
         WRITE (4,*)
 
C     Some quick idiot lights...
 
         IF ( ROT1.LT.0 ) THEN
            WRITE (4,*) 'ROTATION AXIS UNDEFINED'
            STOP
         ENDIF
 
         IF ( ROT1.GT.NATOMS ) THEN
            WRITE (4,*) 'ROTATION AXIS UNDEFINED'
            STOP
         ENDIF
 
         IF ( ROT2.LE.0 ) THEN
            WRITE (4,*) 'ROTATION AXIS UNDEFINED'
            STOP
         ENDIF
 
         IF ( ROT2.GT.NATOMS ) THEN
            WRITE (4,*) 'ROTATION AXIS UNDEFINED'
            STOP
         ENDIF
 
         IF ( NUMROT.GT.(NATOMS-1) ) THEN
            WRITE (4,*) 'ROTATING MOIETY IMPROPERLY DEFINED'
            STOP
         ENDIF
 
         DO 500 I = 1 , NUMROT
            IF ( ROTING1(I).LE.0 ) THEN
               WRITE (4,*) 'ROTATING MOIETY IMPROPERLY DEFINED'
               STOP
            ENDIF
 
            IF ( ROTING1(I).GT.NATOMS ) THEN
               WRITE (4,*) 'ROTATING MOIETY IMPROPERLY DEFINED'
               STOP
            ENDIF
 
 500     CONTINUE
 
C     Begin defining planes as used to determine radial distance to
C     axis of rotation.  Use the coord.s of each axis-defining atom to
C     start, but you need one more point. Take the first atom in the list
C     which is neither ROT1 nor ROT2 to be the other defining point for
C     the first plane.
 
         DO 550 I = 1 , NATOMS
            IF ( I.NE.ROT1 ) THEN
               IF ( I.NE.ROT2 ) GOTO 600
            ENDIF
 550     CONTINUE
 
 600     ATOM3 = I
 
C     If (X2-X1) or (X3-X1) or (Z2-Z1) or (Z3-Z1) is equal to zero, the
C     definition of the planes as here will not work.  So, if this is true,
C     send the coordinates to a subroutine which will rotate the molecule
C     wwhile  leaving it unchanged.
 
 650     TEST12 = ABS(XCOORD(ROT1)-XCOORD(ROT2))
         TEST13 = ABS(XCOORD(ROT1)-XCOORD(ATOM3))
         CONV = 1.0D-06
         IF ( (TEST12.LE.CONV) .OR. (TEST13.LE.CONV) )
     &        CALL ROTATE(XCOORD,YCOORD,ZCOORD,NATOMS)
 
         TEST12 = ABS(ZCOORD(ROT1)-ZCOORD(ROT2))
         TEST13 = ABS(ZCOORD(ROT1)-ZCOORD(ATOM3))
         IF ( (TEST12.LE.CONV) .OR. (TEST13.LE.CONV) )
     &        CALL ROTATE(XCOORD,YCOORD,ZCOORD,NATOMS)
 
         X1 = XCOORD(ROT1)
         Y1 = YCOORD(ROT1)
         Z1 = ZCOORD(ROT1)
 
         X2 = XCOORD(ROT2)
         Y2 = YCOORD(ROT2)
         Z2 = ZCOORD(ROT2)
 
         X3 = XCOORD(ATOM3)
         Y3 = YCOORD(ATOM3)
         Z3 = ZCOORD(ATOM3)
 
C     If it still didn't help, rotate it again.
 
         TEST12 = ABS(X1-X2)
         TEST13 = ABS(X1-X3)
         TESTZ12 = ABS(Z1-Z2)
         TESTZ13 = ABS(Z1-Z3)
 
         IF ( (TEST12.LE.CONV) .OR. (TEST13.LE.CONV) .OR. 
     &        (TESTZ13.LE.CONV) .OR. (TESTZ12.LE.CONV) ) THEN
            CALL ROTATE(XCOORD,YCOORD,ZCOORD,NATOMS)
            GOTO 650
         ENDIF
 
C     Define each plane according to 'Direction Numbers' A, B, C, and D
C     such that Ax+By+Cz+D=0.  Start by fitting the plane through the
C     three atoms selected.  That's why only one can have coordinates of
C     zero.  For simplicity, B=1.
 
         A = ((Y3-Y1)/(Z3-Z1)) - ((Y2-Y1)/(Z2-Z1))
         A1 = A/(((X2-X1)/(Z2-Z1))-((X3-X1)/(Z3-Z1)))
 
         C = ((Y3-Y1)/(X3-X1)) - ((Y2-Y1)/(X2-X1))
         C1 = C/(((Z2-Z1)/(X2-X1))-((Z3-Z1)/(X3-X1)))
 
         D1 = -(A1*X1) - Y1 - (C1*Z1)
 
C     Now, using the two axis-defining atoms and the other plane (which
C     is perpendicular to this one) define the second plane.  The
C     intersection of these two planes is the rotation axis in three
C     dimensions.  Again, B=1.
 
         A = (1/C1) - ((Y2-Y1)/(Z2-Z1))
         A2 = A/(((X2-X1)/(Z2-Z1))-(A1/C1))
 
         C = (1/A1) - ((Y2-Y1)/(X2-X1))
         C2 = C/(((Z2-Z1)/(X2-X1))-(C1/A1))
 
         D2 = -(A2*X1) - Y1 - (C2*Z1)
 
C     Find the distance from each atom to each of the two planes.  Since
C     the planes are perpendicular, the distance to the intersection is
C     the hypoteneuse of the right triangle.  It's not necessary, but
C     to ensure positive radial distances take the absolute values of the
C     distance to each plane.
C     Then use the Pythagorean Theorem to calculate the radial distance of
C     each atom to the rotation axis.
 
         DO 700 I = 1 , NATOMS
            X = XCOORD(I)
            Y = YCOORD(I)
            Z = ZCOORD(I)
            DIST1(I) = ((A1*X)+Y+(C1*Z)+D1)/(SQRT((A1*A1)+1+(C1*C1)))
            DIST1(I) = ABS(DIST1(I))
            DIST2(I) = ((A2*X)+Y+(C2*Z)+D2)/(SQRT((A2*A2)+1+(C2*C2)))
            DIST2(I) = ABS(DIST2(I))
            R(I) = SQRT((DIST1(I)**2)+(DIST2(I)**2))
 700     CONTINUE
 
C     Compute the moment of inertia for the first rotor,  using the
C     formula Im=sum(m*r*r)
 
         MOMENT1 = 0
         DO 750 I = 1 , NUMROT
            MOMENT1 = MOMENT1 + (MASS(ROTING1(I))*R(ROTING1(I))
     &                *R(ROTING1(I)))
 750     CONTINUE
 
         WRITE (4,99006) 
     &                  'MOMENT OF INERTIA ABOUT BOND FOR FIRST MOIETY:'
     &                  , MOMENT1 , 'amu*Ang*Ang'
 
         WRITE (4,*)
 
C     Compute the moment of inertia for the second rotor,  using the
C     formula Im=sum(m*r*r)
 
         MOMENT2 = 0
         DO 800 I = 1 , NUMROT2
            MOMENT2 = MOMENT2 + (MASS(ROTING2(I))*R(ROTING2(I))
     &                *R(ROTING2(I)))
 800     CONTINUE
 
         WRITE (4,99007) 
     &                 'MOMENT OF INERTIA ABOUT BOND FOR SECOND MOIETY:'
     &                 , MOMENT2 , 'amu*Ang*Ang'
 
         WRITE (4,*)
 
         REDMOM = (MOMENT1*MOMENT2)/(MOMENT1+MOMENT2)
         WRITE (4,99008) 
     &                'REDUCED MOMENT OF INERTIA FOR INTERNAL ROTATION:'
     &                , REDMOM , 'amu*Ang*Ang'
         WRITE (4,99009) 'ABOUT THE BOND AXIS DEFINED BY ATOMS' , ROT1 , 
     &                   'AND' , ROT2
      ENDIF
 
      TOTMASS = 0.D+00
      XCM = 0.D+00
      YCM = 0.D+00
      ZCM = 0.D+00
      IXX = 0.D+00
      IYY = 0.D+00
      IZZ = 0.D+00
      IXY = 0.D+00
      IYZ = 0.D+00
      IXZ = 0.D+00
 
C     Calculate center-of-mass of molecule
 
      DO 900 I = 1 , NATOMS
         TOTMASS = TOTMASS + MASS(I)
         XCM = XCM + (MASS(I)*XCOORD(I))
         YCM = YCM + (MASS(I)*YCOORD(I))
         ZCM = ZCM + (MASS(I)*ZCOORD(I))
 900  CONTINUE
 
      XCM = XCM/TOTMASS
      YCM = YCM/TOTMASS
      ZCM = ZCM/TOTMASS
 
C     Use existing coordinates and center-of-mass coordinates to find
C     new, 'internal' coordinates x', y', z'
 
      DO 1000 I = 1 , NATOMS
         XPRIME(I) = XCOORD(I) - XCM
         YPRIME(I) = YCOORD(I) - YCM
         ZPRIME(I) = ZCOORD(I) - ZCM
 
C    Use x', y', and z' to calculate moments and products of inertia
 
         IXX = IXX + (MASS(I)*(YPRIME(I)**2+ZPRIME(I)**2))
         IYY = IYY + (MASS(I)*(XPRIME(I)**2+ZPRIME(I)**2))
         IZZ = IZZ + (MASS(I)*(XPRIME(I)**2+YPRIME(I)**2))
         IXY = IXY + MASS(I)*XPRIME(I)*YPRIME(I)
         IXZ = IXZ + MASS(I)*XPRIME(I)*ZPRIME(I)
         IYZ = IYZ + MASS(I)*YPRIME(I)*ZPRIME(I)
 1000 CONTINUE
 
C     Compose matrix of moments and products of inertia
 
      MAT(1,1) = IXX
      MAT(1,2) = -IXY
      MAT(1,3) = -IXZ
      MAT(2,1) = -IXY
      MAT(2,2) = IYY
      MAT(2,3) = -IYZ
      MAT(3,1) = -IXZ
      MAT(3,2) = -IYZ
      MAT(3,3) = IZZ
 
      N = 3
      NP = 3
      IV = 0
 
C     Find eigenvalues
 
      CALL rs(N,NP,MAT,EIG,IV,ZZ,fv1,fv2,ierr)
 
      WRITE (4,*)
      WRITE (4,*) ' PRINCIPAL MOMENTS OF INERTIA (amu*Ang*Ang):'
      WRITE (4,99010) 'IA=' , EIG(1) , 'IB=' , EIG(2) , 'IC=' , EIG(3)
 
99001 FORMAT (A100)
99002 FORMAT ('MomInert-',A6,5X,A12,/,
     &        '   John R. Barker and Nicolas F. Ortiz',/
     &        '   jrbarker@umich.edu',/
     &        '   University of Michigan'//)
99003 FORMAT (1X,A6,2X,A6,7X,A1,2(11X,A1))
99004 FORMAT (2X,I3,5X,A6,3(3X,F9.6))
99005 FORMAT (2X,A5,1X,I3,1X,A3,1X,I3,1X,A20)
99006 FORMAT (2X,A46,1X,F9.3,1X,A11)
99007 FORMAT (2X,A47,1X,F9.3,1X,A11)
99008 FORMAT (2X,A48,1X,F9.3,1X,A11)
99009 FORMAT (5X,A31,1X,I3,1X,A3,1X,I3)
99010 FORMAT (3X,3(2X,A3,2X,F9.4))
 
      END
