**==colnorm.spg  processed by SPAG 5.11R  at 20:12 on 26 Mar 2001
      SUBROUTINE COLNORM(Mol,Temp)
 
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
c
c MultiWell: a code for chemical kinetics calculations.
c Copyright (C) 2001 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful,
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
c
c	Normalization for a down-step model given
c		in FUNCTION PDOWN(E,EE,Mol,Temp,Hs)
c
c		Mol	= index of molecule
c		Temp	= translational temperature
c	 	E	= initial energy
c		EE	= final energy
c		DC	= coefficients for stepsize distribution
c		Hs	= characteristic stepsize at energy E (calculated by PDOWN)
c
c	Note that COLLUP and CNORM are 'double arrays' with the first
c	imax1+1 elements starting at E = 0 with Egrain1 spacing; the remaining
c	elements are at Egrain2 spacing, starting at E = 0.
c
c	Coefficients stored in array DC
c	Probability of up-steps stored in COLLUP(MaxWell,Isize)
c	Normalization factor (up + down) stored in CNORM(MaxWell,Isize)
c
c	ERROR	= Convergence criterion
c	EDIFF 	= Minimum integration interval (cm-1)
c	FRACT  	= Step-size relative to 'Hs'
c	ITERS  	= Iterations on up-steps
c
      IMPLICIT NONE
 
      INCLUDE 'declare1.inc'
      INCLUDE 'declare3.inc'
 
      DOUBLE PRECISION PDOWN , DENVR , Temp , CNORMI , ETOP , CNORMJ , 
     &                 RATIO , DELMAX
 
      DOUBLE PRECISION B , DENI , E , EE , Hs , PROB , H , DENJ , TERM , 
     &                 SPAN , TLAST , TEST , DOUBNTERP , Fcoll , a , 
     &                 AA , FcollE , ERROR , TESTH
 
      INTEGER I , J , K , Mol , ITERS
 
      DOUBLE PRECISION CN
      DIMENSION CN(Isize)
 
      EXTERNAL PDOWN , DENVR , RAN1 , DOUBNTERP , Fcoll
 
      PARAMETER (ITERS=4,ERROR=1.E-5)
 
      SAVE 
      WRITE (*,99001) Mol
 
c	Integrate over down steps (temporarily store down-step integrals in COLLUP)
c
      COLLUP(Mol,1) = 0.0D+00
      COLLUP(Mol,imax1+1) = 0.0D+00
 
      DO 100 I = 2 , Isize
 
         IF ( I.LE.imax1 ) THEN
            E = (I-1)*Egrain1
         ELSE
            E = (I-imax1-1)*Egrain2
         ENDIF
         DENI = DENVR(Mol,E)                            ! Density at E(I)
 
         IF ( DENI.GE.0.001 ) THEN      !  ONLY IF STATE, OTHERWISE SKIP
 
            TEST = 1.0
            COLLUP(Mol,I) = 0.0D+00     ! Temporary storage of down-normalization
            EE = E
            PROB = PDOWN(E,EE,Mol,Temp,Hs)
            DELMAX = MIN(10.*Hs,10.*Temp/1.4388)   ! Range of integration = 10kT or 10x<deltaE>
            H = FRACT*Hs
            TLAST = PROB                                        ! Initial Hs and 'old' TERM
            DO WHILE ( (TEST.GT.ERROR) .AND. (EE.GT.0.0) )      ! ********** DOWN STEPS **********
               IF ( (EE-H).GE.Emax1 ) THEN
                  H = FRACT*Hs                                  ! Integration step size
               ELSE
                  H = Egrain1
               ENDIF
               IF ( H.GT.EE ) H = EE
               EE = EE - H
               DENJ = DENVR(Mol,EE)
               IF ( DENJ.GE.0.001 ) THEN
                  PROB = PDOWN(E,EE,Mol,Temp,Hs)                ! E > EE
                  TERM = PROB
               ELSE
                  TERM = 0.0D+00
               ENDIF
 
               TESTH = ABS(H-Egrain1)
               IF ( TESTH.GT.0.001 .AND. TLAST.GT.0.0 ) THEN
                  a = -LOG(TERM/TLAST)/H                        ! Exponential form
                  AA = TLAST                                    ! Exponential form
                  SPAN = (AA/a)*(1.0D+00-EXP(-a*H))             ! Exponential form: integral
               ELSE
                  SPAN = 0.5D+00*H*(TERM+TLAST)                 ! Trapezoidal Rule: integral
               ENDIF
 
               COLLUP(Mol,I) = COLLUP(Mol,I) + SPAN
 
               IF ( SPAN.GT.0.0 .AND. ABS(E-EE).GT.DELMAX )
     &              TEST = ABS(SPAN/COLLUP(Mol,I))
               TLAST = TERM                                     ! 'old' TERM
 
            ENDDO
         ENDIF
 100  CONTINUE
      WRITE (*,99002)
 
c		! ********** UP STEPS ***********
c*************************************************************
c	First approximation for normalization: (down-integral + Hs)
 
      DO 200 I = 1 , Isize
         IF ( I.LE.imax1 ) THEN
            E = (I-1)*Egrain1
         ELSE
            E = (I-imax1-1)*Egrain2
         ENDIF
         EE = E
         PROB = PDOWN(E,EE,Mol,Temp,Hs)
         CNORM(Mol,I) = COLLUP(Mol,I) + Hs*Temp/(Hs+Temp)
 200  CONTINUE
 
      DO 400 K = 1 , ITERS      ! Start Iterations
 
         DO 250 I = Isize , 1 , -1      ! REVERSE ORDER
            CN(I) = COLLUP(Mol,I)       ! Initialize by setting equal to down integral
 
            IF ( I.LE.imax1 ) THEN
               E = (I-1)*Egrain1
            ELSE
               E = (I-imax1-1)*Egrain2
            ENDIF
 
            CNORMI = DOUBNTERP(E,Mol,CNORM)
            DENI = DENVR(Mol,E)                 ! Density at E(I)
            IF ( DENI.GE.0.001 ) THEN           !  PROCEED ONLY IF STATE PRESENT
 
               EE = E
               FcollE = Fcoll(Mol,E)
               PROB = PDOWN(E,EE,Mol,Temp,Hs)
               DELMAX = MIN(Viblo(Mol)+10.*Hs,10.*Temp/1.4388)
                                                        ! 10kT or 10x<E>+lowest vib. frequency
               ETOP = E + 10.*DELMAX
               TLAST = PROB                                     ! Initial Hs and 'old' TERM
               TEST = 1.0
 
               DO WHILE ( TEST.GT.ERROR .AND. (EE-E).LT.ETOP )
                  IF ( EE.GE.Emax1 ) THEN
                     H = FRACT*MIN(Temp/1.4388,Hs)
                  ELSE
                     H = Egrain1
                  ENDIF
                  EE = EE + H
                  DENJ = DENVR(Mol,EE)
                  CNORMJ = DOUBNTERP(EE,Mol,CNORM)
                  IF ( DENJ.GE.0.001 .AND. CNORMJ.GT.0.0 .AND. 
     &                 FcollE.GT.0.0 ) THEN
                     B = EXP(-(EE-E)*1.4388/Temp)       ! EE > E
                     PROB = PDOWN(EE,E,Mol,Temp,Hs)     ! EE > E
                     RATIO = (CNORMI/CNORMJ)*(DENJ/DENI)
     &                       *(Fcoll(Mol,EE)/FcollE)
                                                ! inelastic collision fraction
                     TERM = B*PROB*RATIO
                  ELSE
                     TERM = 0.0D+00
                  ENDIF
 
                  TESTH = ABS(H-Egrain1)
                  IF ( TESTH.GT.0.001 .AND. TLAST.GT.0.0 ) THEN
                     a = -LOG(TERM/TLAST)/H                     ! Exponential form
                     AA = TLAST                                 ! Exponential form
                     SPAN = (AA/a)*(1.0D+00-EXP(-a*H))                  ! Exponential form
                  ELSE
                     SPAN = 0.5D+00*H*(TERM+TLAST)              ! Trapezoidal Rule
                  ENDIF
 
                  TLAST = TERM                          ! 'old' value of TERM
                  CN(I) = CN(I) + SPAN
 
                  IF ( SPAN.GT.0.0 .AND. ABS(E-EE).GT.DELMAX )
     &                 TEST = ABS(SPAN/CN(I))
               ENDDO
            ENDIF
 250     CONTINUE       ! end energy steps
 
         DO 300 J = 1 , Isize
            CNORM(Mol,J) = CN(J)                ! Re-load temporary CN (normalization)
 300     CONTINUE
 
 400  CONTINUE          ! End iterations
 
c	Now calculate final COLLUP array
      DO 500 I = 1 , Isize
         IF ( CNORM(Mol,I).GT.0.0D+00 ) THEN
            COLLUP(Mol,I) = 1.0D+00 - COLLUP(Mol,I)/CNORM(Mol,I)
         ELSE
            COLLUP(Mol,I) = 0.0D+00
         ENDIF
 500  CONTINUE
      WRITE (*,99003)
 
      RETURN
 
99001 FORMAT ('Entering Subroutine COLNORM: Molecule #',I2)
 
99002 FORMAT ('    Finished down steps, starting up-steps')
 
99003 FORMAT ('Leaving Subroutine COLNORM'/)
      END
