**==colstep.spg  processed by SPAG 5.11R  at 20:12 on 26 Mar 2001
      DOUBLE PRECISION FUNCTION COLSTEP(Mol,E,Temp)
 
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
c
c MultiWell: a code for chemical kinetics calculations.
c Copyright (C) 2001 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful,
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
C
C     FROM RANDOM NUMBER RON AND ENERGY E COMPUTE A COLLISIONAL
C     STEP SIZE FROM THE NORMALIZED CUMULATIVE DISTRIBUTION 
C     FUNCTION CORRESPONDING TO THE COLLISIONAL DOWN-STEP MODEL:
C
C	IFLAG2 = -1 FOR DOWN-STEPS
C	IFLAG2 = +1 FOR UP-STEPS
C
c	Step-size distribution given in FUNCTION PDOWN(E,EE,Mol,Temp,Hs)
c
c		Mol	= index of molecule
c		Temp	= translational temperature
c	 	E	= initial energy
c		EE	= final energy
c		DC	= coefficients for stepsize distribution
c		Hs	= characteristic stepsize at energy E (calculated by PDOWN
c
c	Note that COLLUP and CNORM are 'double arrays' with the first
c	imax1+1 elements starting at E = 0 with Egrain1 spacing; the remaining
c	elements are at Egrain2 spacing, starting at E = 0.
c
c	Coefficients stored in array DC
c	Probability of up-steps stored in COLLUP(MaxWell,Isize)
c	Normalization factor (up + down) stored in CNORM(MaxWell,Isize)
c
c	ERROR	= Convergence criterion
c	EDIFF 	= Minimum integration interval (cm-1)
c	FRACT  	= Step-size relative to 'Hs'
c	ITERS  	= Iterations on up-steps
c
      IMPLICIT NONE
 
      INCLUDE 'declare1.inc'
      INCLUDE 'declare3.inc'
 
      DOUBLE PRECISION PDOWN , DENVR , Temp , CNORMI , CNORMJ , 
     &                 DOUBNTERP , RATIO , CD
 
      DOUBLE PRECISION UP , RON , TOT , ADOWN , AUP , B , RAN1 , a , 
     &                 AA , Ht , arg , DELMAX , FcollE , ERR , TEST , 
     &                 TESTH
 
      INTEGER Mol , IFLAG2
 
      DOUBLE PRECISION DENI , E , EE , Hs , PROB , H , DENJ , TERM , 
     &                 SPAN , TLAST , Fcoll
 
      EXTERNAL DENVR , PDOWN , RAN1 , Fcoll
 
      SAVE 
 
      IF ( E.LE.Emax1 ) THEN
         ERR = 0.1*ERRo
      ELSE
         ERR = ERRo
      ENDIF
      DENI = DENVR(Mol,E)                               ! DENI = Density at E
      CNORMI = DOUBNTERP(E,Mol,CNORM)   ! CNORMI = Normalization at E
 
      PROB = PDOWN(E,E,Mol,Temp,Hs)     ! Evaluate to get initial Hs
      DELMAX = MIN(Viblo(Mol)+10.*Hs,10.*Temp/1.4388)   ! 10kT or 10x<E>+lowest vib freq
      UP = DOUBNTERP(E,Mol,COLLUP)      ! UP = COLLUP at E
      RON = RAN1(IDUM)
      IF ( RON.LT.UP ) THEN             ! Select up-steps, or down-steps
         IFLAG2 = 1                     ! Up-step
      ELSE
         IFLAG2 = -1                    ! Down-step
      ENDIF
 
 
c ******************** Down steps ***************
      IF ( IFLAG2.EQ.-1 ) THEN                  !  Integrate over down steps
 
         CD = (1.-ERR)*CNORMI*(1.-UP)
         RON = RAN1(IDUM)
 50      ADOWN = RON*CD !  Random-number-selected integral of down-steps
         TLAST = PROB                           ! 'old' TERM
         TOT = 0.0
         EE = E
         H = Egrain1
         TEST = 1.0
 
         DO WHILE ( TOT.LT.ADOWN .AND. EE.GT.0. .AND. TEST.GT.ERR )
            IF ( (EE-H).GE.Emax1 ) THEN
               H = FRACT*Hs
            ELSE
               H = Egrain1
            ENDIF
            IF ( H.GT.EE ) H = EE
            EE = EE - H
            DENJ = DENVR(Mol,EE)
            IF ( DENJ.GE.0.001 ) THEN
               PROB = PDOWN(E,EE,Mol,Temp,Hs)   ! E > EE
               TERM = PROB
            ELSE
               TERM = 0.0D+00
            ENDIF
 
            IF ( H.GT.Egrain1 .AND. TLAST.GT.0.0D+00 ) THEN
               a = -LOG(TERM/TLAST)/H                           ! Exponential form
               AA = TLAST                                       ! Exponential form
               SPAN = (AA/a)*(1.0D+00-EXP(-a*H))                ! Exponential form
            ELSE
               SPAN = 0.5D+00*H*(TERM+TLAST)                    ! Trapezoidal Rule
            ENDIF
 
            TOT = TOT + SPAN                    ! Down-step normalization integral
 
            TLAST = TERM                        ! Old value for TERM
 
            IF ( (E-EE).GT.DELMAX .AND. SPAN.GT.0.0 ) TEST = SPAN/TOT
 
         ENDDO
 
         IF ( TOT.LT.ADOWN ) THEN       ! Invoked when estimated CNORMI is too large
            CD = TOT*(1.0-ERR)          ! Use new cumulative sum
            GOTO 50                     ! Repeat search
         ENDIF
 
         TOT = TOT - SPAN        ! Correction for overshoot
         EE = EE + H
         TESTH = ABS(H-Egrain1)
         IF ( TESTH.GT.0.001 ) THEN     ! TERM must be >0 for E>Emax1
            arg = 1.0D+00 - a*(ADOWN-TOT)/AA
            IF ( arg.GT.0.0 .AND. a.GT.0.0 ) THEN
               Ht = -LOG(abs(arg))/a            ! Exponential form
            ELSE
               Ht = H
            ENDIF
         ELSE
            Ht = H
            DENJ = DENVR(Mol,EE-H)
            IF (DENJ .LE. 0.001) Ht = 0
         ENDIF
         IF ( Ht.GT.H ) Ht = H
         EE = EE - Ht           ! Correction for overshoot
 
      ELSE                                              ! Up-collisions
 
c ******************** Up steps ***************
 
         CD = (1.-ERR)*CNORMI*UP
         RON = RAN1(IDUM)
 100     AUP = RON*CD                   !  Random number-selected
         PROB = PDOWN(E,E,Mol,Temp,Hs)  ! Evaluate to get initial Hs
         TLAST = PROB                           ! 'old' TERM
         TOT = 0.0
         EE = E
         FcollE = Fcoll(Mol,E)
         TEST = 1.0
 
         DO WHILE ( TOT.LT.AUP .AND. TEST.GT.ERR )
            IF ( EE.GE.Emax1 ) THEN
               H = FRACT*MIN(Temp/1.4388,Hs)
            ELSE
               H = Egrain1
            ENDIF
            EE = EE + H
            DENJ = DENVR(Mol,EE)
            CNORMJ = DOUBNTERP(EE,Mol,CNORM)
            IF ( DENJ.GE.0.001 .AND. CNORMJ.GT.0.0 .AND. FcollE.GT.0.0 )
     &           THEN
               B = EXP(-(EE-E)*1.4388/Temp)             ! EE > E
               PROB = PDOWN(EE,E,Mol,Temp,Hs)           ! EE > E
               RATIO = (CNORMI/CNORMJ)*(DENJ/DENI)
     &                 *(Fcoll(Mol,EE)/FcollE)  ! inelastic collision fraction
               TERM = B*PROB*RATIO
            ELSE
               TERM = 0.0D+00
            ENDIF
 
            TESTH = ABS(H-Egrain1)
            IF ( TESTH.GT.0.001 .AND. TLAST.GT.0.0 ) THEN
               a = -LOG(TERM/TLAST)/H                           ! Exponential form
               AA = TLAST                                       ! Exponential form
               SPAN = (AA/a)*(1.0D+00-EXP(-a*H))                        ! Exponential form
            ELSE
               SPAN = 0.5D+00*H*(TERM+TLAST)                    ! Trapezoidal Rule
            ENDIF
 
            TLAST = TERM                        ! Old value for TERM
            TOT = TOT + SPAN                    ! Up-step normalization integral
 
            IF ( (EE-E).GT.DELMAX .AND. SPAN.GT.0.0 ) TEST = SPAN/TOT
 
         ENDDO
 
         IF ( TOT.LT.(AUP) ) THEN               ! Invoked when estimated CNORMI was too large
            CD = TOT*(1.0-ERR)          ! Use new cumulative sum
            GOTO 100                    ! Repeat search
         ENDIF
 
         TOT = TOT - SPAN        ! Correction for overshoot
         EE = EE - H
         TESTH = ABS(H-Egrain1)
         IF ( TESTH.GT.0.001 ) THEN     ! TERM must be >0 for E>Emax1
            arg = 1.0D+00 - a*(AUP-TOT)/AA
            IF ( arg.GT.0.0 .AND. a.GT.0.0 ) THEN
               Ht = -LOG(abs(arg))/a            ! Exponential form
            ELSE
               Ht = H
            ENDIF
         ELSE
            Ht = H
            DENJ = DENVR(Mol,EE+H)
            IF (DENJ .LE. 0.001) Ht = 0
         ENDIF

         IF ( Ht.GT.H ) Ht = H
         EE = EE + Ht           ! Correction for overshoot
 
      ENDIF
 
      IF ( EE.LT.0.0 ) EE = 0.0
      IF ( EE.GT.Emax2 ) EE = Emax2
 
      COLSTEP = EE - E

c      write(*,*) EE, E, (EE-E), TOT, DENJ, CD

      RETURN
      END
