**==estart.spg  processed by SPAG 5.11R  at 20:12 on 26 Mar 2001
      DOUBLE PRECISION FUNCTION Estart(Iflag,Icalc,IR,Molinit,Einit,T)
 
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
c
c MultiWell: a code for chemical kinetics calculations.
c Copyright (C) 2002 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful,
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c     09/04  v1.4.1  -BUG FIX: fixed bug in Pstart for thermal with energy 
c                     offset. 
c     08/03  v1.3.3  -BUG FIX: fixed expression for Estart to conform to 
c                     array bounds.
c     01/02  v1.2.0  -New Feature: can optionally choose to apply centrifugal
c                     corrections for any choice of model. Thus can apply them
c                     even when using Inverse Laplace Transform form of k(E).
c                     NOTE: this new feature affects the data file format.
c     09/01  v1.1.2  -Revised centrigfugal corrections to k(E)'s.
c                     See Robinson & Holbrook (1972) 
c                     eq. 4.30 and 4.31.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c		Selects initial energy for trial
c
c	Iflag	= 0	Initialize Pstart
c		= 1	select Estart from Pstart
c	Icalc	= type of initial distribution
c		= 1	Monoenergetic at energy Einit
c		= 2	Thermal with energy offset Einit
c		= 3	Chemical activation from 'product' #IR
c		= 4	Read Pstart from file 'MultiWell.pstart'
c	IR	= index of 'product' from which chemical activation originates
c	Molinit	= index of initial molecule (well)
c	Einit	= initial energy (relative to ZPE of Molinit; units: cm-1)
c	T	= Temperature (vibrational)
c       Edels   = lowest energy (cm-1) of distribution (e.g. energy offset)
c
      IMPLICIT NONE
 
      INCLUDE 'declare1.inc'
 
      INTEGER i , Iflag , ichan , Icalc , Molinit , IR , IE , IRUN , 
     &        itest , IA
 
      DOUBLE PRECISION AA , RX , E , T , RAN1 , DENVR , Einit , 
     &                 X , Y , Y1 , Y2 , Y3 , Term , Tlast , Etherm
 
      EXTERNAL Etherm
 
      SAVE 
 
      IF ( Iflag.EQ.0 ) THEN                    ! Initialize Pstart
 
         IF ( Icalc.EQ.1 ) THEN                 ! DELTA FUNCTION: No need for initialization
            RETURN
 
         ELSEIF ( Icalc.EQ.4 ) THEN             ! READ NORMALIZED CUMULATIVE DISTRIBUTION FROM FILE
cMAC            OPEN(12,FILE='DensData:'//'multiwell.pstart', STATUS='OLD')	! Data file for starting distribution
            OPEN (12,FILE='DensData/'//'multiwell.pstart',STATUS='OLD')
            READ (12,*) IA , Edels , Hstart     ! Edels and Hstart entered in cm-1; IA is dummy integer
            IF ( IA.NE.Jsize ) THEN
               PAUSE 'Pstart array is wrong length; hit RETURN'
               STOP
            ENDIF
            Einit = Edels
            DO 20 i = 1 , Jsize
               READ (12,*) AA , Pstart(i)       ! AA is dummy real variable
 20         CONTINUE
            CLOSE (12)
            RETURN
 
         ELSEIF ( Icalc.EQ.2 ) THEN                     ! THERMAL DISTRIBUTION
            Edels = Einit                               ! Offset

         ELSEIF ( Icalc.EQ.3 ) THEN                     ! CHEMICAL ACTIVATION
            itest = 0
            DO 40 i = 1 , Nchan(Molinit)                ! Find reaction index
               IF ( Jto(Molinit,i).EQ.IR ) THEN
                  ichan = i
                  itest = 1
               ENDIF
 40         CONTINUE
            IF ( itest.EQ.0 ) THEN
               WRITE (6,99001) Molinit , IR
               PAUSE
               STOP
            ENDIF
            Edels = Eor(Molinit,ichan)                   ! Offset (incorporates centrifugal correction)
            Einit = Edels
         ENDIF
 
         Hstart = 3.d+00*Etherm(Molinit,T)/Jsize        ! Set step size
         Hstart = MAX(Egrain1,Hstart)                   ! Make sure step size not too small

         Tlast = 0.0D+00
         DO 50 i = 1 , Jsize
            E = Edels + (i-1)*Hstart
            IF ( Icalc.EQ.3 ) THEN                      ! CHEMICAL ACTIVATION
               CALL NTERP((E-Edels),IE,X)
               Y1 = Rate(Molinit,ichan,IE-1)
               Y2 = Rate(Molinit,ichan,IE)
               Y3 = Rate(Molinit,ichan,IE+1)
               CALL QUDINT(Y1,Y2,Y3,X,Y)
               Y = exp(Y)                               ! Rate constant k(E) [stored as log]
               Term = Y*DENVR(Molinit,E)*exp(-1.4388*E/T)
            ELSEIF ( Icalc.EQ.2 ) THEN                  ! THERMAL + OFFSET
               Term = DENVR(Molinit,E-Edels)*exp(-1.4388*(E-Edels)/T)
            ENDIF
            Pstart(i) = 0.5D+00*Hstart*(Term+Tlast)     ! Trapezoidal rule
            Tlast=Term
 50      CONTINUE
 
         DO 100 i = 2 , Jsize
            Pstart(i) = Pstart(i) + Pstart(i-1)          ! Cumulative
 100     CONTINUE
 
         DO 150 i = 1 , Jsize
            Pstart(i) = Pstart(i)/Pstart(Jsize)          ! Normalize Cumulative distribution
 150     CONTINUE
 
c ---------------------------------------------------------------------------------
      ELSEIF ( Iflag.EQ.1 ) THEN                ! Select initial energy from Pstart
 
         IF ( Icalc.EQ.1 ) THEN
            Estart = Einit                              ! For delta function
            RETURN
         ELSE
 
            RX = RAN1(IDUM)
 
            i = 0
            IRUN = 1
            DO WHILE ( IRUN.EQ.1 )
               i = i + 1
               IF ( Pstart(i).GT.RX ) IRUN = 0
            ENDDO
 
            Nstart(i) = Nstart(i) + 1           ! Record selected distribution for posterity
 
            IF ( i .GT. 1 ) THEN
               Estart = Edels + Hstart*( (i-1) -
     &             (Pstart(i)-RX)/(Pstart(i) - Pstart(i-1)) )
              ELSE
               Estart = Edels
            ENDIF
 
         ENDIF  ! Icalc
      ENDIF     ! Iflag
      RETURN
 
99001 FORMAT (/'Data file error: Direct rxn does not exist:',I3,' to',
     &        I3/'****** Hit RETURN to terminate run *******')
      END
