
      PROGRAM MultiWell
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c MultiWell: a code for chemical kinetics calculations.
c Copyright (C) 2003 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful,
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c
c	VERSION HISTORY
c 10/03  v1.3.3   (JP) trimmed defined-length character strings with lenstr
c 08/03  v1.3.3b -BUG FIX: fixed problem in subroutine colstep.f that caused
c                 population to become trapped in energy grains that contained 
c                 no states.
c                -BUG FIX: fixed problem in estart.f, in which the lower array
c                 bounds were violated.
c 04/03  v1.3.2  -New Feature: optionally enter total concentration
c                 (molecule/cc) in place of total pressure [use Punit key 
c                 word 'MCC'].
c 01/03  V1.3.1  -Small changes in format of output files
c 08/02  v1.2.3  -Bug Fix: in subroutine book1.f, fixed bug that gave 
c                 erroneously large yields wen the time scale was much shorter
c                 than the inverse of the sum of the rates (k(E) + collision
c                 frequency).
c 01/02  v1.2.0  -New Feature: can optionally choose to apply centrifugal
c                 corrections for any choice of model. Thus can apply them
c                 even when using Inverse Laplace Transform form of k(E).
c                 NOTE: this new feature affects the data file format.
c 11/01  v1.1.4  -Bug Fix: previous version applied centrifugal correction 
c                 inconsistently when calculating Arrhenius parameters 
c                 (k(inf) was correct, however).
c 11/01   v1.1.3 -Bug fix in DenSum and in Thermo, not in MultiWell itself.
c 09/01   v1.1.2 -New feature: time limit (Tlim) set by specifying max time, 
c                 or by specifying max number of collisions. Makes fall-off 
c                 calculations more efficient.
c                -New feature: short summary output file (MultiWell.SUM)
c                 designed to make fall-off calculations more efficient.
c                -Fixed bug in centrifugal corrections to rate constants.
c                 Bug was most evident when the moment of inertia ratio 
c                 (I+/I) was significantly different from unity.
c 04/01   v1.1.1 -Maintenance revision; fixed energy distribution (EDIST)
c                 so that it is normalized according to Ntrials; EDIST is
c                 also reported as a "snapshot", instead of a time average.
c 03/01   v1.1   -New release with many changes. In particular, error in
c                     chemical activation option was fixed.
c 11/99   v1.01  -Revised to compile on LINUX and UNIX; no functional changes.
c 09/99   v1.0   -Macintosh version for Absoft F77 compiler.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
      IMPLICIT NONE
 
      INCLUDE 'declare1.inc'
      INCLUDE 'declare2.inc'
 
      CHARACTER TITLE*100 , FROMTO*10 , TS*10 , Punits*3 , bar*3 , 
     &          atm*3 , tor*3 , POUT*4 , Eunits*4 , kcal*4 , kjou*4 ,
     &          cmm1*4 , Tspec*4 , mcc*3

      CHARACTER AVERSION*6, ADATE*12
      PARAMETER (AVERSION='1.4.1 ', ADATE='SEP 2004' )
 
      PARAMETER (FROMTO=' From...To ',bar='BAR',atm='ATM',tor='TOR',
     &           mcc='MCC',cmm1='CM-1',kcal='KCAL',kjou='KJOU')
 
      INTEGER i , j , k , l , Nforward , M , Ntrials , Igo , IPP , II , 
     &        Mol , Nreac , ito , Jr , Icalc , IR , Molinit , JJ , 
     &        Mdum , Np , Ip , NumTot , IDUM0 , ncen , lenstr
 
      DOUBLE PRECISION Temp , P(50) , PP(50) , Sig , Eps , Amu , Sigma , 
     &                 Epsil , Mass , pi , Time , E , XRANST , AA , EE , 
     &                 Einit , RR , SigM , EpsM , AmuM , CollFreq
 
      DOUBLE PRECISION FracMol(MaxWell+MaxProd) , AveE(MaxWell+MaxProd)
     &                 , Test , SCALE , NumbDens , DistStep , Tvib , 
     &                 klj , kqm ,Tread
 
      DOUBLE PRECISION RAN1 , Etherm , PDOWN , Estart , 
     &                 Kinf(MaxWell,MaxChan) , Ainf(MaxWell,MaxChan) , 
     &                 Einf(MaxWell,MaxChan) , Var(MaxWell+MaxProd) , 
     &                 Pfact , Rob_1 , Delt , 
     &                 Flux(MaxWell,MaxChan,Ntime)
 
      EXTERNAL RAN1 , Etherm , PDOWN , Estart
 
      SAVE 
 
      pi = 4.0D+00*DATAN(1.0D+00)
 
c
c	I/O Unit numbers
c
      KIN = 2   ! Data file
      KOUT = 3  ! General time-dependent output
      KSMM = 5  ! Short summary of output file 
      KSTD = 6  ! standard output (screen)
      KARY = 7  ! Summary of array variables
      KDIST = 8 ! vib distribution
      KRAT = 10 ! average rate 'constants'
      KFLX = 11 ! relative reactive flux via a given path
 
c	OPEN statements for Macintosh (Absoft f77 v. 4.5 compiler).
c	Here, CREATOR designates TexEdit, a convenient share-ware word processor;
c		other word processors can be designated, or omitted.
c	The empty file name in the first statement results in a selection box display.
 
cMAC      OPEN(KIN,  FILE='', STATUS='OLD')						! Data file
cMAC      OPEN(KOUT, FILE='multiwell.out',  CREATOR='TBB6',STATUS='UNKNOWN')	! General time-dependent output
cMAC      OPEN(KSMM, FILE='multiwell.sum',  CREATOR='TBB6',STATUS='UNKNOWN')	! Short summary output for fall-off calculations
cMAC      OPEN(KARY, FILE='multiwell.array',CREATOR='TBB6',STATUS='UNKNOWN')	! Summary of array variables
cMAC      OPEN(KDIST,FILE='multiwell.dist', CREATOR='TBB6',STATUS='UNKNOWN')	! vib distribution
cMAC      OPEN(KRAT, FILE='multiwell.rate', CREATOR='TBB6',STATUS='UNKNOWN')	! average rate 'constants'
cMAC      OPEN(KFLX, FILE='multiwell.flux', CREATOR='TBB6',STATUS='UNKNOWN')	! relative reactive flux via a given path
 
c		OPEN statements for non-Macintosh
      OPEN (KIN,FILE='multiwell.dat',STATUS='OLD')              ! Data file
      OPEN (KOUT,FILE='multiwell.out',STATUS='UNKNOWN')         ! General time-dependent output
      OPEN (KSMM,FILE='multiwell.sum',STATUS='UNKNOWN')         ! Short summary output for fall-off calculations
      OPEN (KARY,FILE='multiwell.array',STATUS='UNKNOWN')       ! Summary of array variables
      OPEN (KDIST,FILE='multiwell.dist',STATUS='UNKNOWN')       ! vib distribution
      OPEN (KRAT,FILE='multiwell.rate',STATUS='UNKNOWN')        ! average rate 'constants'
      OPEN (KFLX,FILE='multiwell.flux',STATUS='UNKNOWN')	! relative reactive flux via a given path
 
      WRITE (KOUT,99001) AVERSION , ADATE
      WRITE (KSMM,99001) AVERSION , ADATE
      WRITE (KARY,99001) AVERSION , ADATE
      WRITE (KDIST,99001) AVERSION , ADATE
      WRITE (KRAT,99001) AVERSION , ADATE
 
      CALL DateTime(KOUT)
      CALL DateTime(KSMM)
      CALL DateTime(KARY)
      CALL DateTime(KDIST)
      CALL DateTime(KRAT)
 
      READ (KIN,99003) TITLE
      WRITE (KOUT,99003) TITLE
      WRITE (KSMM,99003) TITLE
      WRITE (KARY,99003) TITLE
      WRITE (KDIST,99003) TITLE
      WRITE (KRAT,99003) TITLE
      WRITE (KFLX,99003) TITLE
 
      READ (KIN,*) Egrain1 , imax1 , k , Emax2 , IDUM
      IF ( k.NE.Isize ) THEN
         WRITE (KSTD,99002) Isize
         PAUSE
         STOP
      ENDIF
      Emax1 = Egrain1*(imax1-1)
      Egrain2 = Emax2/(Isize-imax1-1)
c.......................................................................
c	Energy grain parameters for interpolation 'double arrays'
c
c	'Double arrays' have two sections:
c		segment 1 consists of equally spaced (Egrain1) values ranging
c			from E=0 to Emax1
c		segment 2 consists of equally spaced values from E=0 to Emax2;
c			the spacing depends on the number of array elements
c			remaining: Isize-Emax1/Egrain1-1
c
c	Egrain1	= energy grain of lower segments in 'double array' (units: cm-1)
c	Emax1	= maximum energy of 1st segment of double array (units: cm-1)
c	Emax2	= maximum energy of 2nd segment of double array (units: cm-1)
c	IDUM	= random number seed (positive, non-zero integer)
c.......................................................................
c
 
      IF ( IDUM.EQ.0 ) IDUM = 1990339   ! Random number seed
      IDUM = -ABS(IDUM)
      XRANST = RAN1(IDUM)    ! initialize RAN1
      WRITE (KOUT,99044) Egrain1 , Emax1 , imax1 , Egrain2 , Emax2 , 
     &                   (Isize-imax1)
      WRITE (KSMM,99044) Egrain1 , Emax1 , imax1 , Egrain2 , Emax2 , 
     &                   (Isize-imax1)
      WRITE (KARY,99044) Egrain1 , Emax1 , imax1 , Egrain2 , Emax2 , 
     &                   (Isize-imax1)
      WRITE (KDIST,99044) Egrain1 , Emax1 , imax1 , Egrain2 , Emax2 , 
     &                    (Isize-imax1)
      WRITE (KRAT,99044) Egrain1 , Emax1 , imax1 , Egrain2 , Emax2 , 
     &                   (Isize-imax1)
      WRITE (KFLX,99044) Egrain1 , Emax1 , imax1 , Egrain2 , Emax2 , 
     &                   (Isize-imax1)
 
      READ (KIN,*) Punits , Eunits
c.......................................................................
c	Key words for units
c
c	Punits	= pressure units key word [use upper case CHARACTER*3]
c		= 'BAR', 'ATM', 'TOR' [also will accept 'TORR']. or 'MCC'
c	Eunits	= energy units keyword [use upper case CHARACTER*4]
c		= 'CM-1','KCAL', or 'KJOU' for cm-1, kcal/mole, or kJ/mole
c.......................................................................
c	Physical parameters
c
c	Temp	= translational temperature (units: degrees Kelvin)
c	Tvib	= vibrational temperature (units: degrees Kelvin)
c	Np	= number of pressures
c	PP	= vector of Np pressures
c.......................................................................
      READ (KIN,*) Temp , Tvib
      READ (KIN,*) Np
      READ (KIN,*) (PP(i),i=1,Np)
      IF ( Np.GT.50 ) THEN
         PAUSE 'More than 50 pressures....Hit RETURN'
         STOP
      ENDIF
c.......................................................................
c
c	Convert pressures to bars
c
c.......................................................................
      IF ( Punits.EQ.atm ) THEN
         POUT = 'atm '
         Pfact = 1.01325
      ELSEIF ( Punits.EQ.tor ) THEN
         POUT = 'Torr'
         Pfact = 1.01325/760.
      ELSEIF ( Punits.EQ.bar ) THEN
         POUT = 'bar '
         Pfact = 1.0
      ELSEIF ( Punits.EQ.mcc ) THEN
         POUT = '1/cc '
         Pfact = Temp/7.2428D+21
      ELSE
         PAUSE 'Pressure units not specified properly....Hit RETURN'
         STOP
      ENDIF
 
      DO 100 i = 1 , Np
         P(i) = PP(i)*Pfact
 100  CONTINUE
 
      READ (KIN,*) NWells , NProds
      DO 200 i = 1 , NWells
         READ (KIN,*) IMol(i) , MolName(i) , HMol(i) , MolMom(i) , 
     &                Molsym(i) , Molele(i) , Molopt(i) , Iread(i) , 
     &                SMol(i) , RotMol(i) , ZPEMol(i) , BetMol(i) , 
     &                HvMol(i)
         IF ( Eunits.EQ.kcal ) THEN
            HMol(i) = HMol(i)*349.881           ! Convert kcal/mole to cm-1
         ELSEIF ( Eunits.EQ.kjou ) THEN
            HMol(i) = HMol(i)*83.5936           ! Convert kJ/mole to cm-1
         ENDIF
         Nchan(i) = 0                           ! Initialize Nchan
 200  CONTINUE
 
      DO 300 i = NWells + 1 , NWells + NProds
         READ (KIN,*) IMol(i) , MolName(i)
 300  CONTINUE
c.......................................................................
c	Reactant/Product parameters
c
c	NWells	= number of 'wells'
c	NProds	= number of entrance/exit species
c
c	IMol	= index number for molecule
c	MolName	= name (10 characters) of molecule
c	HMol	= enthalpy of formation at 0K
c	MolMom	= moment of inertia for 2-dim external rotor (amu Ang^2)
c	Molsym	= external symmetry number for molecule
c	Molele	= electronic degeneracy for molecule
c	Molopt	= number of optical isomers for molecule
c	Iread	= 0: calculate densities from W-R
c		= 1: read densities from file
c		  *** filename: same name as MolName +'.dens'
c		  ***    e.g. 'Benzene.dens'
c	SMol	= number of vibrational degrees of freedom
c		= 0 for irreversible product species
c	RotMol	= number of rotational degrees of freedom
c	ZPEMol	= total vibrational zero point energy (units: cm-1)
c	BetMol	= Whitten-Rabinovitch beta
c	HvMol	= geometric mean vibrational frequency (units: cm-1)
c
c	(The last four items are used only for the W-R density calculations,
c	but they must be included in the data line, perhaps as zeros.)
c.......................................................................
 
      CALL DensArray                            ! Calculate or read densities
 
 
      WRITE (KARY,99031) NWells , Temp , Tvib
      WRITE (KARY,99036) (i,i=1,NWells)
      WRITE (KARY,99035) (MolName(i),i=1,NWells)
      WRITE (KARY,99023) (HMol(i),i=1,NWells)
      WRITE (KARY,99025) (HMol(i)/83.5936,i=1,NWells)
      WRITE (KARY,99024) (HMol(i)/349.881,i=1,NWells)
      WRITE (KARY,99033) (Viblo(i),i=1,NWells)
      WRITE (KARY,99045) (MolMom(i),i=1,NWells)
      WRITE (KARY,99046) (Molsym(i),i=1,NWells)
      WRITE (KARY,99047) (Molele(i),i=1,NWells)
      WRITE (KARY,99048) (Molopt(i),i=1,NWells)
      WRITE (KARY,99042) (SMol(i),i=1,NWells)
      WRITE (KARY,99037) (RotMol(i),i=1,NWells)
      WRITE (KARY,99038) (ZPEMol(i),i=1,NWells)
      WRITE (KARY,99039) (BetMol(i),i=1,NWells)
      WRITE (KARY,99040) (HvMol(i),i=1,NWells)
      WRITE (KARY,99041) (Etherm(i,Temp),i=1,NWells)
      WRITE (KARY,99043) (Iread(i),i=1,NWells)
 
      WRITE (KARY,99009)
 
      WRITE (KARY,99032) NProds
      WRITE (KARY,99072) (i,MolName(i),i=NWells+1,NProds+NWells)
 
      WRITE (KOUT,99031) NWells , Temp , Tvib
      WRITE (KOUT,99036) (i,i=1,NWells)
      WRITE (KOUT,99035) (MolName(i),i=1,NWells)
      WRITE (KOUT,99023) (HMol(i),i=1,NWells)
      WRITE (KOUT,99025) (HMol(i)/83.5936,i=1,NWells)
      WRITE (KOUT,99024) (HMol(i)/349.881,i=1,NWells)
      WRITE (KOUT,99033) (Viblo(i),i=1,NWells)
      WRITE (KOUT,99045) (MolMom(i),i=1,NWells)
      WRITE (KOUT,99046) (Molsym(i),i=1,NWells)
      WRITE (KOUT,99047) (Molele(i),i=1,NWells)
      WRITE (KOUT,99048) (Molopt(i),i=1,NWells)
      WRITE (KOUT,99042) (SMol(i),i=1,NWells)
      WRITE (KOUT,99037) (RotMol(i),i=1,NWells)
      WRITE (KOUT,99038) (ZPEMol(i),i=1,NWells)
      WRITE (KOUT,99039) (BetMol(i),i=1,NWells)
      WRITE (KOUT,99040) (HvMol(i),i=1,NWells)
      WRITE (KOUT,99041) (Etherm(i,Temp),i=1,NWells)
      WRITE (KOUT,99043) (Iread(i),i=1,NWells)
 
      WRITE (KOUT,99009)
 
      WRITE (KOUT,99032) NProds
      WRITE (KOUT,99072) (i,MolName(i),i=NWells+1,NProds+NWells)
 
      WRITE (KSMM,99031) NWells , Temp , Tvib
      WRITE (KSMM,99036) (i,i=1,NWells)
      WRITE (KSMM,99035) (MolName(i),i=1,NWells)
      WRITE (KSMM,99023) (HMol(i),i=1,NWells)
      WRITE (KSMM,99025) (HMol(i)/83.5936,i=1,NWells)
      WRITE (KSMM,99024) (HMol(i)/349.881,i=1,NWells)
      WRITE (KSMM,99033) (Viblo(i),i=1,NWells)
      WRITE (KSMM,99045) (MolMom(i),i=1,NWells)
      WRITE (KSMM,99046) (Molsym(i),i=1,NWells)
      WRITE (KSMM,99047) (Molele(i),i=1,NWells)
      WRITE (KSMM,99048) (Molopt(i),i=1,NWells)
      WRITE (KSMM,99042) (SMol(i),i=1,NWells)
      WRITE (KSMM,99037) (RotMol(i),i=1,NWells)
      WRITE (KSMM,99038) (ZPEMol(i),i=1,NWells)
      WRITE (KSMM,99039) (BetMol(i),i=1,NWells)
      WRITE (KSMM,99040) (HvMol(i),i=1,NWells)
      WRITE (KSMM,99041) (Etherm(i,Temp),i=1,NWells)
      WRITE (KSMM,99043) (Iread(i),i=1,NWells)
 
      WRITE (KSMM,99009)
 
      WRITE (KSMM,99032) NProds
      WRITE (KSMM,99072) (i,MolName(i),i=NWells+1,NProds+NWells)
 
      WRITE (KARY,99010) (MolName(i),i=1,NWells)
      DO 400 II = 1 , Isize
         IF ( II.LE.imax1 ) THEN
            E = (II-1)*Egrain1
         ELSE
            E = (II-imax1-1)*Egrain2
         ENDIF
         WRITE (KARY,99011) E , (exp(Dens(i,II)),i=1,NWells)
                                                        ! Densities stored as logs
 400  CONTINUE
 
      WRITE(KOUT,99073) NWells
      READ (KIN,*) SigM , EpsM , AmuM , Amu
c.......................................................................
c	Collision parameters - collider
c
c	SigM	L-J sigma (Ang) for collider
c	EpsM	L-J Eps (Kelvins) for collider
c	AmuM	Molecular weight (g/mole) of collider
      WRITE (KOUT,99055)
      WRITE (KSMM,99055)
      WRITE (KARY,99055)
      Mdum = 0
      WRITE (KOUT,99056) Mdum , SigM , EpsM , AmuM
      WRITE (KSMM,99056) Mdum , SigM , EpsM , AmuM
      WRITE (KARY,99056) Mdum , SigM , EpsM , AmuM
 
      DO 500 j = 1 , NWells
         READ (KIN,*) Mol , Sig , Eps , ITYPE(Mol) , (DC(Mol,i),i=1,8)
         READ (KIN,*) LJQM(Mol)
         IF ( LJQM(Mol).EQ.QM ) READ (KIN,*) (CE(Mol,i),i=1,3)
c.......................................................................
c	Collision parameters
c
c	Sig	L-J sigma (Ang) for molecule
c	Eps	L-J Eps (Kelvins) for molecule
c	Amu	Molecular weight (g/mole) of molecule
c	ITYPE	selects model type in Subroutine PDOWN
c	DC	coefficients for collision model
c	LJQM	= 'LJ' for Lennard-Jones collision frequency, ALL collisions inelastic
c		= 'QM' for total cross section collision frequency and a finite
c		  elastic collision probability
c	CE	coefficients for inelastic collision probability (Function Fcoll)
c.......................................................................
c
         Sigma = 0.5*(SigM+Sig)
         Epsil = SQRT(EpsM*Eps)
         Mass = AmuM*Amu/(AmuM+Amu)
 
         klj = pi*1.E-16*(Sigma**2)*1.45525E+04*SQRT(Temp/Mass)
     &         /(0.636+0.246*LOG(Temp/Epsil))   ! L-J collision integral
 
         kqm = 7.64E-12*((Epsil*Sigma**6)**0.4)*(Temp/Mass)**0.3
                                                                ! Max quantum rate constant
         IF ( LJQM(Mol).EQ.LJ ) THEN
            CollK(Mol) = klj
         ELSE
            CollK(Mol) = kqm
         ENDIF
c.......................................................................
c
c	klj = L-J collision frequency (s-1)
c	kqm = collision frequency based on the total quantum cross section
c		[Durant and Kaufman, Chem. Phys. Letters, 142, 246 (1987)]
c.......................................................................
c
         WRITE (KOUT,99056) Mol , Sig , Eps , Amu , Sigma , Epsil , 
     &                      Mass , klj , kqm , CollK(Mol)
         WRITE (KSMM,99056) Mol , Sig , Eps , Amu , Sigma , Epsil , 
     &                      Mass , klj , kqm , CollK(Mol)
         WRITE (KARY,99056) Mol , Sig , Eps , Amu , Sigma , Epsil , 
     &                      Mass , klj , kqm , CollK(Mol)
 500  CONTINUE
c
c	Call PDOWN WITH E=-1.0 in order to store LI(Mol,i) in COMMON for print-out
c
      WRITE (KOUT,99030)
      WRITE (KSMM,99030)
      WRITE (KARY,99030)
 
      DO 600 Mol = 1 , NWells
         CALL COLNORM(Mol,Temp)         ! Calculate COLLUP and CNORM arrays
         Rob_1 = -1.0
         XRANST = PDOWN(Rob_1,Rob_1,Mol,Temp,SCALE)
         WRITE (KOUT,99057) Mol , MolName(Mol)(1:lenstr(Mol))
     &   , (DC(Mol,i),i=1,8)
         WRITE (KOUT,99027) (LI(Mol,i),i=1,5)
         WRITE (KSMM,99057) Mol , MolName(Mol)(1:lenstr(Mol))
     &   , (DC(Mol,i),i=1,8)
         WRITE (KSMM,99027) (LI(Mol,i),i=1,5)
         WRITE (KARY,99057) Mol , MolName(Mol)(1:lenstr(Mol))
     &   , (DC(Mol,i),i=1,8)
         WRITE (KARY,99027) (LI(Mol,i),i=1,5)
         IF ( LJQM(Mol).EQ.QM ) THEN
            WRITE (KOUT,99058) (CE(Mol,i),i=1,3)
            WRITE (KSMM,99058) (CE(Mol,i),i=1,3)
            WRITE (KARY,99058) (CE(Mol,i),i=1,3)
         ENDIF
 600  CONTINUE
 
      WRITE (KARY,99030)
      WRITE (KARY,99012) (Mol,Mol,Mol=1,NWells)
      DO 700 II = 1 , Isize
         IF ( II.LE.imax1 ) THEN
            E = (II-1)*Egrain1
         ELSE
            E = (II-imax1-1)*Egrain2
         ENDIF
         WRITE (KARY,99011) E , 
     &                      (CNORM(Mol,II),COLLUP(Mol,II),Mol=1,NWells)
 700  CONTINUE
 
 
      READ (KIN,*) Nforward
      Nreac = Nforward
 
      WRITE(KOUT,99074) Nforward

      DO 800 i = 1 , Nforward
 
         READ (KIN,*) Mol , ito , TS , RR , ncen , 
     &                j , k , l , JJ , Jr , AA , EE
         WRITE (KOUT,99075) i,Mol , ito , TS , RR , ncen , 
     &                j , k , l , JJ , Jr , AA , EE
c.......................................................................
c	Reaction parameters
c
c	Nforward= number of reaction parameters to be input (forward rxns, only)
c	Mol	= index of reactant molecule
c	ito	= Jto	 = index of product molecule
c	TS	= TSname = Name of transition state (up to 10 characters)
c	RR	= TSmom  = moment of inertia (amu.ang^2)
c       ncen    = NCENT  = 0 for no quasi-diatomic centrifugal correction
c               = NCENT  = 1 for quasi-diatomic centrifugal correction
c	j	= TSsym  = external symmetry number for TS
c	k	= TSele	 = electronic degeneracy number for TS
c	l	= TSopt	 = number of optical isomers for TS
c	JJ	= Jread	 = 0 for calculating k(E) internally via inverse Laplace
c		= 1 for reading sums of states from external file
c		  *** filename: same name as TSame +'.dens'
c		  ***   e.g. 'TS-1.dens'
c		= 2 for reading k(E) from external file (Jrev must =0)
c		  *** filename: same name as TSame +'.rke'
c		  ***   e.g. 'TS-1.rke'
c	Jr	= 0 for neglecting the reverse reaction [Jrev = JR]
c		= 1 for calculating reverse rxn rate; after calculation,
c			Jrev=1 is changed to Jrev=2
c	AA	= Afact	= A-factor for reaction (units: s-1)
c	EE	= Eo	= critical energy, relative to ZPE of reactant
c.......................................................................
c
c
c	Nchan	= number of rxn channels originating from a given molecule
c.......................................................................
 
         Nchan(Mol) = Nchan(Mol) + 1
         Jto(Mol,Nchan(Mol)) = ito
         TSname(Mol,Nchan(Mol)) = TS
         TSmom(Mol,Nchan(Mol)) = RR
         NCENT(Mol,Nchan(Mol)) = ncen
         TSsym(Mol,Nchan(Mol)) = j
         TSele(Mol,Nchan(Mol)) = k
         TSopt(Mol,Nchan(Mol)) = l
         Jread(Mol,Nchan(Mol)) = JJ
         Jrev(Mol,Nchan(Mol)) = Jr
         Afac(Mol,Nchan(Mol)) = AA
         IF ( Eunits.EQ.cmm1 ) THEN
            Eo(Mol,Nchan(Mol)) = EE                     ! cm-1 units
         ELSEIF ( Eunits.EQ.kcal ) THEN
            Eo(Mol,Nchan(Mol)) = EE*349.881             ! Convert kcal/mole to cm-1
         ELSEIF ( Eunits.EQ.kjou ) THEN
            Eo(Mol,Nchan(Mol)) = EE*83.5936             ! Convert kJ/mole to cm-1
         ENDIF
         Hts(Mol,ito) = HMol(Mol) + Eo(Mol,Nchan(Mol))  ! Rxn barrier enthalpy
         Hts(ito,Mol) = Hts(Mol,ito)                    ! Rxn barrier enthalpy
         IF ( Jr.EQ.1 ) THEN                    ! Jr=1 for rev rxn required
            IF ( SMol(ito).EQ.0 ) THEN
               Jrev(Mol,Nchan(Mol)) = 0 ! If 'ito' is an irreversible product molecule
            ELSE
               Nreac = Nreac + 1
               Nchan(ito) = Nchan(ito) + 1
               Jto(ito,Nchan(ito)) = Mol
               TSname(ito,Nchan(ito)) = TS
               TSmom(ito,Nchan(ito)) = RR
               NCENT(ito,Nchan(ito)) = NCENT(Mol,Nchan(Mol))
               TSsym(ito,Nchan(ito)) = j
               TSele(ito,Nchan(ito)) = k
               TSopt(ito,Nchan(ito)) = l
               Jrev(ito,Nchan(ito)) = 0
               IF ( JJ.EQ.2 ) THEN
                  Jread(ito,Nchan(ito)) = -2
                                        ! RateArray will read k(E) for forward rxn and then calculate reverse k(E)
               ELSE
                  Jread(ito,Nchan(ito)) = JJ
               ENDIF
               Afac(ito,Nchan(ito)) = AA
               Eo(ito,Nchan(ito)) = Hts(ito,Mol) - HMol(ito)
            ENDIF
         ENDIF
 
 800  CONTINUE
 
      CALL RateArray(Temp)                              ! Calculate rate constants
 
      DO 900 j = 1 , NWells
         DO 850 i = 1 , Nchan(j)
            CALL QKinf(j,i,Temp,Kinf(j,i),Ainf(j,i),Einf(j,i))
 850     CONTINUE
 900  CONTINUE
 
      WRITE (KOUT,99013)  Nreac
      WRITE (KOUT,99121) (FROMTO,i=1,Nreac)
      WRITE (KOUT,99028) ((j,Jto(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99034) ((TSname(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99045) ((TSmom(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99046) ((TSsym(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99047) ((TSele(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99048) ((TSopt(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99026) ((Path(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99023) ((Hts(j,Jto(j,i)),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99025) ((Hts(j,Jto(j,i))/83.5936,i=1,Nchan(j)),j=1,
     &                   NWells)
      WRITE (KOUT,99024) ((Hts(j,Jto(j,i))/349.881,i=1,Nchan(j)),j=1,
     &                   NWells)
      WRITE (KOUT,99021) ((Eo(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99022) ((Eo(j,i)/83.5936,i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99020) ((Eo(j,i)/349.881,i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99029) ((Kinf(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99049) ((Ainf(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99050) ((Einf(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99051) ((Einf(j,i)*4.184,i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99115) ((NCENT(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99114) ((Eor(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99052) ((Jread(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KOUT,99053)
 
      WRITE (KSMM,99013)  Nreac
      WRITE (KSMM,99121) (FROMTO,i=1,Nreac)
      WRITE (KSMM,99028) ((j,Jto(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99034) ((TSname(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99045) ((TSmom(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99046) ((TSsym(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99047) ((TSele(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99048) ((TSopt(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99026) ((Path(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99023) ((Hts(j,Jto(j,i)),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99025) ((Hts(j,Jto(j,i))/83.5936,i=1,Nchan(j)),j=1,
     &                   NWells)
      WRITE (KSMM,99024) ((Hts(j,Jto(j,i))/349.881,i=1,Nchan(j)),j=1,
     &                   NWells)
      WRITE (KSMM,99021) ((Eo(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99022) ((Eo(j,i)/83.5936,i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99020) ((Eo(j,i)/349.881,i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99029) ((Kinf(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99049) ((Ainf(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99050) ((Einf(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99051) ((Einf(j,i)*4.184,i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99115) ((NCENT(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99114) ((Eor(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99052) ((Jread(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KSMM,99053)
 
      WRITE (KARY,99030)
      WRITE (KARY,99034) ((TSname(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99045) ((TSmom(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99046) ((TSsym(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99047) ((TSele(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99048) ((TSopt(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99026) ((Path(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99023) ((Hts(j,Jto(j,i)),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99025) ((Hts(j,Jto(j,i))/83.5936,i=1,Nchan(j)),j=1,
     &                   NWells)
      WRITE (KARY,99024) ((Hts(j,Jto(j,i))/349.881,i=1,Nchan(j)),j=1,
     &                   NWells)
      WRITE (KARY,99021) ((Eo(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99022) ((Eo(j,i)/83.5936,i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99020) ((Eo(j,i)/349.881,i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99029) ((Kinf(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99049) ((Ainf(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99050) ((Einf(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99051) ((Einf(j,i)*4.184,i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99115) ((NCENT(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99114) ((Eor(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99052) ((Jread(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99053)
      WRITE (KARY,99013)  Nreac
      WRITE (KARY,99113) ((Eor(j,i),i=1,Nchan(j)),j=1,NWells)
      WRITE (KARY,99121) (FROMTO,i=1,Nreac)
      WRITE (KARY,99016) ((j,Jto(j,i),i=1,Nchan(j)),j=1,NWells)
 
      DO 1000 II = 1 , Isize
         IF ( II.LE.imax1 ) THEN
            E = (II-1)*Egrain1
         ELSE
            E = (II-imax1-1)*Egrain2
         ENDIF
         WRITE (KARY,99018) E , 
     &                      ((EXP(Rate(j,i,II)),i=1,Nchan(j)),j=1,NWells
     &                      )
 1000 CONTINUE
 
      READ (KIN,*) Ntrials , Tspec , Tread , Icalc , Molinit , IR , 
     &                Einit
      IF ( Eunits.EQ.kcal ) THEN
         Einit = Einit*349.881          ! Convert kcal/mole to cm-1
      ELSEIF ( Eunits.EQ.kjou ) THEN
         Einit = Einit*83.5936          ! Convert kJ/mole to cm-1
      ENDIF
 
c.......................................................................
c	Ntrials	= number of trials
c	Tspec	= time specification (CHARACTER*4)
c		= 'TIME': Tread = Tlim (max time)
c		= 'COLL': Tread = max collisions, from which Tlim is calculated 
c	Tread	= maximum simulated time
c	Icalc	= type of initial distribution
c		= 0	Initialize by calculating cumulative distribution
c		= 1	Monoenergetic at energy Einit
c		= 2	Thermal with energy offset Einit
c		= 3	Chemical activation from 'product' #IR
c	Molinit	= index of initial molecule
c	IR	= origin of initial molecule, if produced via chemical activation
c	Einit	= initial energy (relative to ZPE of Molinit)
c.......................................................................
c
 
         WRITE (KSMM,99059) Ntrials
         IF ( Icalc.EQ.1 ) THEN
            WRITE (KSMM,99165) Temp , MolName(Molinit) , 
     &                         Einit , IDUM0 , IDUM
         ELSEIF ( Icalc.EQ.2 ) THEN
            WRITE (KSMM,99166) Tvib , Temp , MolName(Molinit) , 
     &                         Einit , IDUM0 , IDUM
         ELSEIF ( Icalc.EQ.3 ) THEN
            WRITE (KSMM,99167) Tvib , Temp , MolName(Molinit) ,
     &                         MolName(IR) , IDUM0 , IDUM
         ENDIF
 
         WRITE (KSMM,99063) (MolName(i),i=1,NWells+NProds)
         WRITE (KSMM,99060) (HMol(i),i=1,NWells)
         WRITE (KSMM,99161) POUT , (i,i,i=1,NWells+NProds)

c
c	Initialize Estart to calculate cumulative distribution
c
      E = Estart(0,Icalc,IR,Molinit,Einit,Tvib)
 
c @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
c
c	START PRESSURE STEPS & TRIALS
c
c
      DO 1200 Ip = 1 , Np               ! Pressure steps
         NumbDens = P(Ip)*7.2428D+21/Temp
         CollFreq = CollK(Molinit)*NumbDens

         IF ( Tspec.EQ.'TIME' ) THEN           ! Specify max time
            Tlim = Tread
         ELSEIF ( Tspec.EQ.'COLL') THEN       ! Specify max number of collisions
           IF (Tread .GT. 0.0d+00) THEN
              Tlim = Tread/CollFreq
           ELSE
              Tlim = 100.
           ENDIF
         ENDIF

         Tstep = Tlim/(Ntime-1)
         IDUM0 = IDUM
 
         CALL INITIAL                   ! Initialize bookkeeping arrays
 
         M = 0
         WRITE (*,99064) M , M
 
         DO 1050 M = 1 , Ntrials
            E = Estart(1,Icalc,IR,Molinit,Einit,Tvib)
            Igo = 1
            Mol = Molinit
            Time = 0.0D+00               ! Initialize
            DO WHILE ( Igo.EQ.1 )
               CALL STEPPER(Mol,E,Temp,NumbDens,IPP,Delt)
               CALL BOOK1(Mol,E,Temp,IPP,Time,Delt,Igo)
               IF ( Time.GT.Tlim ) Igo = 0
            ENDDO
            Test = 20.*M/Ntrials - (20*M/Ntrials)
            IF ( ABS(Test).LT.1.E-06 ) WRITE (*,99064) M , 
     &           5*(20*M/Ntrials)
 1050    CONTINUE
c
c
c	Massage booked results and store output
c
         CALL DateTime(KOUT)
         CALL DateTime(KARY)
 
         WRITE (KOUT,99059) Ntrials
         WRITE (KARY,99059) Ntrials
         WRITE (KRAT,99059) Ntrials
         WRITE (KFLX,99059) Ntrials
         IF ( Icalc.EQ.1 ) THEN
            WRITE (KOUT,99065) Temp , PP(Ip) , POUT , NumbDens , 
     &                         CollFreq , MolName(Molinit) , 
     &                         Einit , IDUM0 , IDUM
            WRITE (KARY,99065) Temp , PP(Ip) , POUT , NumbDens , 
     &                         CollFreq , MolName(Molinit) , 
     &                         Einit , IDUM0 , IDUM
            WRITE (KRAT,99065) Temp , PP(Ip) , POUT , NumbDens , 
     &                         CollFreq , MolName(Molinit) , 
     &                         Einit , IDUM0 , IDUM
            WRITE (KFLX,99065) Temp , PP(Ip) , POUT , NumbDens , 
     &                         CollFreq , MolName(Molinit) , 
     &                         Einit , IDUM0 , IDUM
         ELSEIF ( Icalc.EQ.2 ) THEN
            WRITE (KOUT,99066) Tvib , Temp , PP(Ip) , POUT , NumbDens , 
     &                         CollFreq , MolName(Molinit) , 
     &                         Einit , IDUM0 , IDUM
            WRITE (KARY,99066) Tvib , Temp , PP(Ip) , POUT , NumbDens , 
     &                         CollFreq , MolName(Molinit) , 
     &                         Einit , IDUM0 , IDUM
            WRITE (KRAT,99066) Tvib , Temp , PP(Ip) , POUT , NumbDens , 
     &                         CollFreq , MolName(Molinit) , 
     &                         Einit , IDUM0 , IDUM
            WRITE (KFLX,99066) Tvib , Temp , PP(Ip) , POUT , NumbDens , 
     &                         CollFreq , MolName(Molinit) , 
     &                         Einit , IDUM0 , IDUM
         ELSEIF ( Icalc.EQ.3 ) THEN
            WRITE (KOUT,99067) Tvib , Temp , PP(Ip) , POUT , NumbDens , 
     &                         CollFreq , MolName(Molinit) , MolName(IR)
     &                         , IDUM0 , IDUM
            WRITE (KARY,99067) Tvib , Temp , PP(Ip) , POUT , NumbDens , 
     &                         CollFreq , MolName(Molinit) , MolName(IR)
     &                         , IDUM0 , IDUM
            WRITE (KRAT,99067) Tvib , Temp , PP(Ip) , POUT , NumbDens , 
     &                         CollFreq , MolName(Molinit) , MolName(IR)
     &                         , IDUM0 , IDUM
            WRITE (KFLX,99067) Tvib , Temp , PP(Ip) , POUT , NumbDens , 
     &                         CollFreq , MolName(Molinit) , MolName(IR)
     &                         , IDUM0 , IDUM
         ENDIF
 
         WRITE (KRAT,99030)
         WRITE (KRAT,99034) ((TSname(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99045) ((TSmom(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99046) ((TSsym(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99047) ((TSele(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99048) ((TSopt(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99023) ((Hts(j,Jto(j,i)),i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99024) ((Hts(j,Jto(j,i))/349.881,i=1,Nchan(j)),j=1,
     &                      NWells)
         WRITE (KRAT,99021) ((Eo(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99022) ((Eo(j,i)/83.5936,i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99020) ((Eo(j,i)/349.881,i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99029) ((Kinf(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99049) ((Ainf(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99050) ((Einf(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99051) ((Einf(j,i)*4.184,i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99115) ((NCENT(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99114) ((Eor(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99052) ((Jread(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KRAT,99053)
         WRITE (KRAT,99014) Nreac , (FROMTO,i=1,Nreac)
         WRITE (KRAT,99017) ((j,Jto(j,i),i=1,Nchan(j)),j=1,NWells)
 
         WRITE (KFLX,99030)
         WRITE (KFLX,99034) ((TSname(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99045) ((TSmom(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99046) ((TSsym(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99047) ((TSele(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99048) ((TSopt(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99023) ((Hts(j,Jto(j,i)),i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99024) ((Hts(j,Jto(j,i))/349.881,i=1,Nchan(j)),j=1,
     &                      NWells)
         WRITE (KFLX,99021) ((Eo(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99022) ((Eo(j,i)/83.5936,i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99020) ((Eo(j,i)/349.881,i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99029) ((Kinf(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99049) ((Ainf(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99050) ((Einf(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99051) ((Einf(j,i)*4.184,i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99115) ((NCENT(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99114) ((Eor(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99052) ((Jread(j,i),i=1,Nchan(j)),j=1,NWells)
         WRITE (KFLX,99053)
         WRITE (KFLX,99015) Nreac , (FROMTO,i=1,Nreac)
         WRITE (KFLX,99017) ((j,Jto(j,i),i=1,Nchan(j)),j=1,NWells)
 
c
c	Calculate populations of each molecule
c
         WRITE (KOUT,99063) (MolName(i),i=1,NWells+NProds)
         WRITE (KOUT,99060) (HMol(i),i=1,NWells)
         WRITE (KOUT,99061) (i,i,i=1,NWells+NProds)
         DO 1100 j = 1 , Ntime          ! Start of time-loop
            Time = (j-1)*Tstep
            NumTot = 0
            DO 1060 i = 1 , NWells + NProds
               FracMol(i) = 0.0D+00
               AveE(i) = 0.0D+00
               NumTot = NumTot + Num(i,j)
 1060       CONTINUE
 
            DO 1080 Mol = 1 , NWells + NProds
               FracMol(Mol) = DBLE(Num(Mol,j))/DBLE(NumTot)             ! Average population in each well
               Var(Mol) = SQRT(FracMol(Mol)*(1.0-FracMol(Mol))/DBLE(
     &                    NumTot))
               IF ( Mol.LE.NWells .AND. Num(Mol,j).GT.0 ) THEN
                  AveE(Mol) = EMol(Mol,j)/Num(Mol,j)
                                               ! Average E in each well
                  DO 1065 k = 1 , Nchan(Mol)
                    IF (Nuni(Mol,j).GT.0) THEN
                         kuni(Mol,k,j) = kuni(Mol,k,j)/Nuni(Mol,j)  ! average rate constants
                         Flux(Mol,k,j) = kuni(Mol,k,j)*FracMol(Mol) ! relative reaction flux via a given path
                      ELSE
                         kuni(Mol,k,j) = 0.0d+00
                         Flux(Mol,k,j) = 0.0d+00
                    ENDIF
 1065             CONTINUE
               ENDIF
 1080       CONTINUE
 
            WRITE (KOUT,99062) Time , Time*CollFreq , 
     &                         (FracMol(Mol),Var(Mol),AveE(Mol),Mol=1,
     &                         NWells+NProds)
            WRITE (KRAT,99019) Time , 
     &                         ((kuni(Mol,k,j),k=1,Nchan(Mol)),Mol=1,
     &                         NWells)  ! average rate constants
            WRITE (KFLX,99019) Time , 
     &                         ((Flux(Mol,k,j),k=1,Nchan(Mol)),Mol=1,
     &                         NWells)  ! average rate constants
 1100    CONTINUE                       ! End of time-loop
 
            WRITE (KSMM,99062) PP( Ip ) , NumbDens ,
     &                         (FracMol(Mol),Var(Mol),AveE(Mol),Mol=1,
     &                         NWells+NProds)

         Tstep = Tlim/(Mtime-1)
         DistStep = Emax2/(Ndist-1)     ! Write out energy distributions
         WRITE (KDIST,99070) Temp , Tvib , P(Ip)
 
         DO 1150 Mol = 1 , NWells
            DO 1120 j = 1 , Mtime
               DO 1110 k = 1 , Ndist
                  IF ( EDIST(Mol,k,j).GT.0.0D+00 ) WRITE (KDIST,99071)
     &                 Mol , (j-1)*Tstep , (k-0.5)*DistStep , 
     &                 DBLE(EDIST(Mol,k,j))/DBLE(Ntrials)    ! write non-zero elements
 1110          CONTINUE
 1120       CONTINUE
 1150    CONTINUE
 
         IF ( Icalc.GT.1 ) THEN         ! Only if Thermal or Chemical Activation
            WRITE (KARY,99068)
            DO 1160 II = 1 , Jsize
               E = Einit + (II-1)*Hstart
               IF ( II.GT.1 ) Nstart(II) = Nstart(II) + Nstart(II-1)
               WRITE (KARY,99069) E , Pstart(II) , DBLE(Nstart(II))
     &                            /DBLE(Ntrials)
 1160       CONTINUE
         ENDIF
 1200 CONTINUE                          ! End pressure step loop
 
99001 FORMAT (
     &'%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     &%%%%%%%%%%%%%'//8x,
     &'                                John R. Barker'/8x,
     &'      MultiWell-',A6,'          jrbarker@umich.edu'/8x,
     &'                                University of Michigan'/8x,
     &'        ',A12,'            Ann Arbor, MI 48109-2143'/8x,
     &'                                (734) 763 6239'//8x,
     &'      http://aoss.engin.umich.edu/multiwell/'//
     &'%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     &%%%%%%%%%%%%%'/)
c
c	FORMAT STATEMENTS
c
99002 FORMAT (/'Isize does not equal ',I3,
     &        ' elements.'/'****** Hit RETURN to terminate run *******')
99003 FORMAT (A100)
99004 FORMAT (60x,'DATE: ',I2.2,'/',I2.2,'/',I4.4,/,60x,'TIME: ',I2.2,
     &        ':',I2.2,':',I2.2//)
99005 FORMAT (//I2,1x,'Stable Molecules',//,
     &'No. Name             delH   2D-moment Symm Vibs Rots     ZPE     
     &  beta    <freq>  Thermal<E>')
99006 FORMAT (I2,2x,A10,1x,f10.1,2x,f10.1,2x,I2,2x,I2,2x,I2,1x,0pf10.1,
     &        1x,f10.4,1x,f10.3,1x,f10.1)
99007 FORMAT (I2,2x,A10,1x,f10.1,2x,f10.1,2x,I2,2x,
     &        'Densities from an external file',9x,f10.1)
99008 FORMAT (I2,2x,A10,1x,'      Irreversible product species')
99009 FORMAT (/'   Units:  2D-moment: amu Ang^2'/
     &        '            ZPE,<freq>,Thermal<E>: cm-1'/
     &        '   WR   = Whitten-Rab'/
     &        '   File = densities from external file'/
     &        '   prod = irreversible product species')
99010 FORMAT (/,5X,'Densities of States',/'     Energy',1x,75(1x,A10))
99011 FORMAT (1x,f10.1,75(1x,1pe10.3,1x,1pe10.3))
99012 FORMAT (/'     Energy',75('   Norm(',I2.2,') UpProb(',I2.2,')'))
99013 FORMAT (/,5X,I3,' k(E) RATE CONSTANTS')
99113 FORMAT (7X,'(with rotational corrections) vs. active energy',/,/,
     &           '  Eo+Rot:',75(1x,f10.1),/)
99114 FORMAT ('     Eo+Rot:',75(1x,f10.1))
99115 FORMAT ('Centr.Corr.:',75(1x,I10))
99014 FORMAT (/,5X,I3,' Average Rate Constants',/11X,75(1X,A10))
99015 FORMAT (/,5X,I3,' Relative Reactive Flux',/11X,75(1X,A10))
99016 FORMAT (' Energy',3x,75(4X,I2.2,'...',I2.2))
99017 FORMAT ('   Time',3x,75(4X,I2.2,'...',I2.2))
99018 FORMAT (1x,f10.1,75(1x,1pe10.3))
99019 FORMAT (2x,1pe10.2,75(1x,1pe10.3))
99020 FORMAT ('   Eo(kcal):',75(1x,f10.2))
99121 FORMAT (11X,75(1X,A10))
99021 FORMAT ('   Eo(cm-1):',75(1x,f10.1))
99022 FORMAT ('     Eo(kJ):',75(1x,f10.2))
99023 FORMAT (' delH(cm-1):',75(1x,f10.1))
99024 FORMAT (' delH(kcal):',75(1x,f10.1))
99025 FORMAT ('   delH(kJ):',75(1x,f10.1))
99026 FORMAT ('  Rxn_paths:',75(1x,f10.1))
99027 FORMAT (A100)
99028 FORMAT ('       ',3x,75(4X,I2.2,'...',I2.2))
99029 FORMAT ('     k(inf):',75(1x,1pe10.2))
99030 FORMAT (/)
99031 FORMAT (/I5,' WELLS'/10x,'Translational (Thermal) Temperature =',
     &        f8.1,1x,'K'/10x,'    Initial Vibrational Temperature =',
     &        f8.1,1x,'K'/)
99032 FORMAT (/I5,' PRODUCT SETS')
99033 FORMAT (' lowest_vib:',75(1x,f10.1))
99034 FORMAT ('    TS_Name:',75(1x,A10))
99035 FORMAT (' Molec_Name:',75(1x,A10))
99036 FORMAT ('  Molec_No.:',75(1x,I10))
99037 FORMAT ('       rots:',75(1x,I10))
99038 FORMAT ('        ZPE:',75(1x,f10.1))
99039 FORMAT ('       Beta:',75(1x,f10.4))
99040 FORMAT ('  geo._<hv>:',75(1x,f10.4))
99041 FORMAT ('  Thermal_E:',75(1x,f10.1))
99042 FORMAT ('       vibs:',75(1x,I10))
99043 FORMAT ('Source:O=WR,1=File',I5,75(1x,I10))
99044 FORMAT (/'PARAMETERS FOR DOUBLE-ARRAYS:'/
     &    '        Grain (cm-1)      Maximum Energy    Number of grains'
     &    /2(2F20.3,i20/))
99045 FORMAT ('  2D-moment:',75(1x,f10.1))
99046 FORMAT ('   ext_symm:',75(1x,I10))
99047 FORMAT ('   e-_degen:',75(1x,I10))
99048 FORMAT ('   opt_isom:',75(1x,I10))
99049 FORMAT ('     A(inf):',75(1x,1pe10.2))
99050 FORMAT (' E(inf)kcal:',75(1x,f10.2))
99051 FORMAT ('   E(inf)kJ:',75(1x,f10.2))
99052 FORMAT ('     Source:',75(1x,I10))
99053 FORMAT (
     &'Source:  0=ILT; 1=sums of states file; 2=k(E) file; -2=k(E) file 
     &for reverse rxn')
99054 FORMAT ('Temperature (K) =',f10.2,/,'Pressure (bar) =',1pe10.3/)
99055 FORMAT ('Lennard-Jones Parameters & Pdown Models'/
     &'Mol   Sig(Ang)      Eps/k MolWt(amu)     NetSig   NetEps/k    Red
     &Mass     k(LJ)    k(QM)     Used')
99056 FORMAT (1x,I2,6(1X,f10.3),3(1x,1pe10.3))
99057 FORMAT ('Well number: ',I2,/,'Name: ',A10,/,
     &        'Collision parameters:',/,8(1X,1pe10.3))
99058 FORMAT ('Inelastic collision parameters:',3(1X,1pe10.3))
99059 FORMAT (/'RESULTS FOR',I8,' TRIALS')
99060 FORMAT ('              deltaH(cm-1): ',75(5x,0pf10.1,18x))
99061 FORMAT ('   Time  Collisns(Mol=1)',
     &        75(3x,'Fract(',I2.2,') +/-Error  <Evib(',I2.2,')>'))
99161 FORMAT (3X , A4 , '   molecules/cc  ',
     &        75(3x,'Fract(',I2.2,') +/-Error  <Evib(',I2.2,')>'))
99062 FORMAT (2(1x,1pe10.2),75(3x,1pe10.2,1pe10.2,0pf8.0,2x))
99063 FORMAT ('                      Name:    ',75(5x,A10,18x))
99064 FORMAT (1x,I10,'  Trials = ',I5,' %')
99065 FORMAT ('****Monoenergetic****'/'    Ttrans  = ',f6.1,
     &        ' K',/,'    Press   = ',1pe10.3,1x,A4,/,'          N = ',
     &        1pe10.3,' /cm3',/,'Coll. Freq. = ',
     &        1pe10.3,' /s'/,'Initial Molecule: ',A10,/,'E(initial) =',
     &        0pf10.1,' cm-1',/,'Starting random number seed = ',
     &        I10,/,'Ending   random number seed = ',I10,/)
99066 FORMAT ('****Shifted Thermal (at Tvib)****'/'     Tvib   = ',f6.1,
     &        ' K',/,'     Ttrans = ',f6.1,' K',/,'     Press  = ',
     &        1pe10.3,
     &        1x,A4,/,'          N = ',1pe10.3,' /cm3',/,
     &        'Coll. Freq. = ',
     &        1pe10.3,' /s',/,'Initial Molecule: ',A10,/,'E(shift) =',
     &        0pf10.1,' cm-1'/'Starting random number seed = ',
     &        I10,/,'Ending   random number seed = ',I10,/)
99067 FORMAT ('****Chemical Activation (at Tvib)****'/'     Tvib   = ',
     &        f6.1,' K',/,'     Ttrans = ',f6.1,' K',/,'     Press  = ',
     &        1pe10.3,1x,A4,/'          N = ',
     &        1pe10.3,' /cm3',/,'Coll. Freq. = ',
     &        1pe10.3,' /s',/,'Excited Molecule: ',
     &        A10,/,'   Produced from: ',
     &        A10,/,'Starting random number seed = ',
     &        I10,/,'Ending   random number seed = ',I10,/)
99165 FORMAT (/,/,'****Monoenergetic****'/'    Ttrans  = ',f6.1,
     &        ' K',/,'Initial Molecule: ',A10,/,'E(initial) =',
     &        0pf10.1,' cm-1',/,'Starting random number seed = ',
     &        I10,/,'Ending   random number seed = ',I10,/)
99166 FORMAT (/,/,'****Shifted Thermal (at Tvib)****'/'     Tvib   = ',
     &        f6.1,
     &        ' K',/,'     Ttrans = ',f6.1,' K',/,'Initial Molecule: ',
     &        A10,/,'E(shift) =',
     &        0pf10.1,' cm-1',/,'Starting random number seed = ',
     &        I10,/,'Ending   random number seed = ',I10,/)
99167 FORMAT (/,/,'****Chemical Activation (at Tvib)****'
     &        /'     Tvib   = ',
     &        f6.1,' K',/,'     Ttrans = ',f6.1,' K',/,
     &        'Excited Molecule: ',
     &        A10,/,'   Produced from: ',
     &        A10,/,'Starting random number seed = ',
     &        I10,/,'Ending   random number seed = ',I10,/)
99068 FORMAT (/'CUMULATIVE DISTRIBUTION FXNS FOR STARTING ENERGIES'//
     &        '    ENERGY   P(calc)    P(actual)')
99069 FORMAT (1x,f10.1,2(1x,1pe10.3))
99070 FORMAT (/'Energy Distribution (non-zero elements)',/,
     &        '  (Energy at center of energy bin)',/,' Ttrans=',f6.1,
     &        1x,'K',5x,'Tvib=',f6.1,1x,'K',5x,'P= ',1PE10.3,1x,'bar',/,
     &        ' Molecule  Time  VibEnergy  Distrib')
99071 FORMAT (1x,I3,1x,1pe10.3,1x,0pf10.1,1x,1pe10.3)
99072 FORMAT (75(8x,I3,2x,A10/))
99073 FORMAT (//,'COLLISION PARAMETERS FOR ',I2,' WELLS')
99074 FORMAT (/,'INPUT DATA FILE CHECK: ',I2,' REACTION CHANNELS'/
     &'#  Mol ito TS         RR     ncen  j  k  l  JJ Jr  AA       EE ') 
99075 FORMAT(3(I2,1X),A10,1X,1PE10.2,1X,6(I2,1X),2(1PE10.2,1X))
      END
