**==qkinf.spg  processed by SPAG 5.11R  at 20:12 on 26 Mar 2001
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c MultiWell: a code for chemical kinetics calculations.
c Copyright (C) 2002 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful,
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
c
c     01/02  v1.2.0  -New Feature: can optionally choose to apply centrifugal
c                     corrections for any choice of model. Thus can apply them
c                     even when using Inverse Laplace Transform form of k(E).
c                     NOTE: this new feature affects the data file format.
c     11/01  v1.1.4  -Bug Fix: previous version applied centrifugal correction 
c                     inconsistently when calculating Arrhenius parameters 
c                     (k(inf) was correct, however).
c     09/01  v1.1.2  -Revised centrigfugal corrections to k(E)'s.
c                     See Robinson & Holbrook (1972) eq. 4.30 and 4.31.
c
c***********************************************************************

      SUBROUTINE QKinf(Mol,nchann,tx,Kinf,Ainf,Einf)
      IMPLICIT NONE
      INCLUDE 'declare1.inc'
      INTEGER Mol , nchann , i , IE , Itop , mm
      DOUBLE PRECISION Q , RK , TT , E , D , DENVR , Kinf , Ainf , 
     &                 Einf , K , tx , Et , arg , Y1 , Y2 , Y3 , Y , 
     &                 X , Estep, RR, QQ , Qlast , Rlast , TTSTEP , 
     &                 TS , EC , hor
      DIMENSION K(3), TS(3)
      PARAMETER (hor=1.438775d+00)   ! hc/R for energies in cm-1 units
      SAVE 
c
c	Calculates high pressure limiting unimolecular rate constant according to
c         Equation (4.30) of Robinson & Holbrook, "Unimolecular Reactions"
c         (Wiley-Interscience, London, 1972), p. 90.
c
c	Mol	= index of molecule
c	nchann	= index of rxn channel
c	t	= translational temperature
c	Kinf	= infinite pressure rate constant [Robinson & Holbrook Eq. 4.30]
c	Ainf	= A-factor for kinf
c	Einf	= Activation energy for kinf
c
c
c     Centrifugal correction at temperature = tx
c
      EC =  Eor(Mol,nchann)                 ! Includes centrifugal correction

      TTSTEP = 0.01d+00/tx                  ! Step size in 1/Temp
      TT = 1.0d+00/tx-2.*TTSTEP             ! 1/Temp

      DO 1000 mm = 1,3
        K(mm) = 0.0d+00
        RK = 0.0d+00
        Q  = 0.0d+00
        RR = 0.0d+00
        QQ = 0.0d+00
        Qlast = 0.0d+00
        Rlast = 0.0d+00

        TT = TT + TTSTEP                     ! 1/T
        TS(mm) = TT                          ! 1/T

        Qlast = exp(Dens(Mol,1))             ! At zero energy
        D = DENVR(Mol,EC)                    ! At rxn threshold
        Rlast = D*exp(Rate(Mol,nchann,1))    ! At rxn threshold; k(E) stored as log

        Estep = Egrain1
        E = 0.0d+00

      DO 100 i = 2 , imax1                        ! start at first step above threshold
         E = E + Estep
         QQ = exp(Dens(Mol,i)-E*hor*TT)           ! molecule partition fxn;  density stored as log
         arg = E + EC
         D = DENVR(Mol,arg)
         RR = D*exp(Rate(Mol,nchann,i)-E*hor*TT)  ! thermal rate constant; k(E) stored as log
         Q  = Q  + 0.5*Estep*(QQ + Qlast)         ! Trapezoidal Rule
         RK = RK + 0.5*Estep*(RR + Rlast)
         Qlast = QQ
         Rlast = RR
 100  CONTINUE
c
c          NOW CONTINUE TO HIGHER ENERGIES
c 
      Estep = 0.05d+00/(hor*TT)                    ! Step size (cm-1) expressed as fraction of kT
      Itop = ( 15.0/(hor*TT))/Estep                ! Integral to be extended to 15 kT

      DO 200 i = 1 , Itop                          ! Continuing the integral to higher energies
         E = E + Estep
         D = DENVR(Mol,E)
         QQ = D*exp(-E*hor*TT)
         CALL NTERP(E,IE,X)
         Y1 = Rate(Mol,nchann,IE-1)
         Y2 = Rate(Mol,nchann,IE)
         Y3 = Rate(Mol,nchann,IE+1)
         CALL QUDINT(Y1,Y2,Y3,X,Y)                  ! Y = interpolated ln k(E)
         arg = E + EC
         D = DENVR(Mol,arg)
         RR = D*exp(Y-E*hor*TT)                     ! k(E) stored as log
         Q  = Q  + 0.5*Estep*(QQ + Qlast)           ! Trapezoidal Rule
         RK = RK + 0.5*Estep*(RR + Rlast)
         Qlast = QQ
         Rlast = RR
 200  CONTINUE
 
       RK = RK*exp(-Eo(Mol,nchann)*hor*TT)/Q
       IF ( NCENT(Mol,nchann).EQ.1 ) THEN               ! If Centrifugal Correction
          K(mm) = RK*(TSmom(Mol,nchann)/MolMom(Mol))    ! kinf with Qrot ratio
       ELSE
          K(mm) = RK
       ENDIF

 
1000  CONTINUE

      Kinf = K(2)
      Et = -(LOG(K(3)/K(1)))/(TS(3)-TS(1))                  ! Ea/R
      Ainf = K(2)*exp(Et*TS(2))                             ! 1/s
      Einf = (1.9865d-03)*Et                                ! kcal/mole

      RETURN
      END
