**==ratearray.spg  processed by SPAG 5.11R  at 20:12 on 26 Mar 2001
      SUBROUTINE RateArray(T)
 
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c MultiWell: a code for chemical kinetics calculations.
c Copyright (C) 2002 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful,
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c	k(E) calculated and stored in double array 'Rate'.  Note that
c	reverse rxns are calculated with same sums of states as
c	forward rxns.
c
c	T	= translational temperature
c	Mol	= index of reactant molecule
c	Nchan	= number of channels originating from Mol
c	Jread	= 0  use inverse Laplace transform method for channel
c		= 1  read sums of states for channel from external file
c		= 2  read k(E) for this channel from external file
c	Jto	= index of product molecule
c	Jrev	= 0 for neglecting the reverse reaction
c		= 1 for calculating reverse rxn rate; after calculation,
c			Jrev=1 is changed to Jrev=2
c	Afact	= A-factor for reaction (units: s-1) [for ILT method]
c	Eact	= activation energy (units: cm-1) [for ILT method]
c
c	Note that File name and path in OPEN statements may need revision
c		for non-Macintosh
c
c***********************************************************************
c
c 10/03  v1.3.3  (JP) trimmed defined-length character strings with lenstr.
c 01/02  v1.2.0  -New Feature: can optionally choose to apply centrifugal
c                 corrections for any choice of model. Thus can apply them
c                 even when using Inverse Laplace Transform form of k(E).
c                 NOTE: this new feature affects the data file format.
c 11/01  v1.1.4  -Bug Fix: previous version applied centrifugal correction 
c                 inconsistently when calculating Arrhenius parameters 
c                 (k(inf) was correct, however).
c 09/01  v1.1.2  -Revised centrigfugal corrections to k(E)'s.
c                 See Robinson & Holbrook (1972) eq. 4.30 and 4.31.
c 07/00  v1.1    -All k(E)'s now calculated including Path(Mol,i)
c 07/00  v1.1    -For k(E) read from file, can calculate reverse rxn k(E)
c
c***********************************************************************
      IMPLICIT NONE
      INCLUDE 'declare1.inc'
      INTEGER i , j , Mol , JJ , jdum , lenstr
      DOUBLE PRECISION DENVR , E , EE , DD , A , B , TSsum , T , DUM , 
     &                 ER , Test1 , Test2 , hor
      PARAMETER (hor=1.438775d+00)
      SAVE 
 
      DO 100 Mol = 1 , NWells
 
         IF ( SMol(Mol).GT.0 ) THEN     ! Ensure that Mol has a density of states array
            DO 20 i = 1 , Nchan(Mol)
 
               Path(Mol,i) = DBLE(Molsym(Mol)*TSele(Mol,i)*TSopt(Mol,i))
     &                       /DBLE(TSsym(Mol,i)*Molele(Mol)*Molopt(Mol))
                                                        ! Rxn path degeneracy used for all k(E)
 
               IF ( NCENT(Mol,i) .EQ.1 )THEN
                   Eor(Mol,i) =  Eo(Mol,i)
     &                   + (1.0-TSmom(Mol,i)/MolMom(Mol))*T/hor         ! Centrifugal correction
               ELSE
                   Eor(Mol,i) =  Eo(Mol,i)
               ENDIF                     

               IF ( Jread(Mol,i).EQ.0 ) THEN            ! Inverse-Laplace-Transform !!!!!!!!!!!!!!!!!!!!!!!!!!!
 
                  
                  IF ( NCENT(Mol,i) .EQ.1 )THEN         ! If centrifugal correction, modify A-factor
                      Afac(Mol,i) = Afac(Mol,i)*MolMom(Mol)/TSmom(Mol,i)
                  ENDIF                     

                  DO 5 j = 1 , Isize
                     IF ( j.LE.imax1 ) THEN             ! E = energy from top of barrier
                        E = (j-1)*Egrain1
                     ELSE
                        E = (j-imax1-1)*Egrain2
                     ENDIF
                     EE = E + Eor(Mol,i)                 ! Includes centrifugal correction
                     DD = DENVR(Mol,EE)
                     Rate(Mol,i,j) = Afac(Mol,i)*DENVR(Mol,E)/DD  ! k(E)
                     Rate(Mol,i,j) = LOG(Rate(Mol,i,j))           ! k(E) stored as log
 
 5                CONTINUE
 
               ELSEIF ( Jread(Mol,i).EQ.1 ) THEN        ! Read sums of states from external file !!!!!!!!!!!!!!!!!!!!!!!!!!
cMAC                  OPEN(12,FILE=':DensData:'//
cMAC     &            TSname(Mol,i)(1:lenstr(TSname(Mol,i)))//'.dens',
cMAC     &            STATUS='OLD')				! TST sum of states
                  OPEN (12,FILE='DensData/'//
     &            TSname(Mol,i)(1:lenstr(TSname(Mol,i)))//'.dens',
     &            STATUS='OLD')                   ! TST sum of states
                  READ (12,99001) A , JJ , B , j , DUM
                  Test1 = ABS(A-Egrain1)/1.D-06
                  Test2 = ABS(B-Emax2)/1.D-06
                  IF ( Test1.LT.1.0 .AND. JJ.EQ.imax1 .AND. 
     &                 Test2.LT.1.0 .AND. j.EQ.Isize ) THEN
                                                ! Test for proper array bounds, etc.
                     DO 6 j = 1 , Isize
                        READ (12,*) jdum , A , B , TSsum        ! Read sum of states  (here, A and B are dummy variables)
                        IF ( j.LE.imax1 ) THEN                  ! E = active energy from top of barrier
                           E = (j-1)*Egrain1
                        ELSE
                           E = (j-imax1-1)*Egrain2
                        ENDIF
                        EE = E + Eor(Mol,i)                             ! Includes centrifugal correction
                        DD = TSsum/DENVR(Mol,EE)
                        Rate(Mol,i,j) = 2.9979D+10*DD*Path(Mol,i)       ! k(E)
                        Rate(Mol,i,j) = LOG(Rate(Mol,i,j))              ! k(E) stored as log
  6                   CONTINUE
                  ELSE                               ! If grain or energy limit does not match
                     WRITE (KSTD,99002) TSname(Mol,i)
                     PAUSE
                     STOP
                  ENDIF
                  CLOSE (12)
 
               ELSEIF ( Jread(Mol,i).EQ.2 ) THEN        ! Read k(E)'s (not including path degeneracy) from external file !!!!!!!!!!!!!!!!!!!!!!!!!!!
cMAC                  OPEN(12,FILE=':DensData:'//
cMAC     &            TSname(Mol,i)(1:lenstr(TSname(Mol,i)))//'.rke',
cMAC     &            STATUS='OLD')				! k(E)'s
                  OPEN (12,FILE='DensData/'//
     &            TSname(Mol,i)(1:lenstr(TSname(Mol,i)))//'.rke',
     &            STATUS='OLD')                   ! k(E)'s
                  READ (12,99001) A , JJ , B , j
                  Test1 = ABS(A-Egrain1)/1.D-06
                  Test2 = ABS(B-Emax2)/1.D-06
                  IF ( Test1.LT.1.0 .AND. JJ.EQ.imax1 .AND. 
     &                 Test2.LT.1.0 .AND. j.EQ.Isize ) THEN
                                                ! Test for proper array bounds, etc.
                     DO 8 j = 1 , Isize
                        READ (12,*) jdum , A , B , Rate(Mol,i,j)
                                                        ! Read k(E)'s
                        IF ( Rate(Mol,i,j).GT.1.D-20 ) THEN
                           Rate(Mol,i,j) = LOG(Rate(Mol,i,j))
                                                        ! k(E) stored as log
                        ELSE
                           Rate(Mol,i,j) = LOG(1.D-20)  ! k(E) stored as log
                        ENDIF
 8                   CONTINUE
                  ELSE                  ! If grain or energy limit does not match
                     WRITE (KSTD,99002) TSname(Mol,i)
                     PAUSE
                     STOP
                  ENDIF
                  CLOSE (12)
 
               ELSEIF ( Jread(Mol,i).EQ.-2 ) THEN       ! Read k(E)'s (not including path degeneracy) for REVERSE rxn !!!!!!!!!!!!!!!!!!!!!!!!!!!
cMAC                  OPEN(12,FILE=':DensData:'//
cMAC     &            TSname(Mol,i)(1:lenstr(TSname(Mol,i)))//'.rke',
cMAC     &            STATUS='OLD')				! k(E)'s for REVERSE rxn
                  OPEN (12,FILE='DensData/'//
     &            TSname(Mol,i)(1:lenstr(TSname(Mol,i)))//'.rke',
     &            STATUS='OLD')                   ! k(E)'s for REVERSE rxn
                  READ (12,99001) A , JJ , B , j
                  Test1 = ABS(A-Egrain1)/1.D-06
                  Test2 = ABS(B-Emax2)/1.D-06
                  IF ( Test1.LT.1.0 .AND. JJ.EQ.imax1 .AND. 
     &                 Test2.LT.1.0 .AND. j.EQ.Isize ) THEN
                                                ! Test for proper array bounds, etc.
                     DO 10 j = 1 , Isize
                        READ (12,*) jdum , A , B , Rate(Mol,i,j)
                                                                ! Read k(E)'s (not including path degeneracy) for REVERSE reaction
 
                        IF ( j.LE.imax1 ) THEN                  ! E = energy from top of barrier
                           E = (j-1)*Egrain1                    ! Energy in forward direction
                        ELSE
                           E = (j-imax1-1)*Egrain2              ! Energy in forward direction
                        ENDIF
                        E = E + Eor(Mol,i)                      ! With rotational correction
                        ER = E - (HMol(Jto(Mol,i))-HMol(Mol))   ! Energy in reverse direction
                        DD = DENVR(Jto(Mol,i),ER)/DENVR(Mol,E)  ! Density of states ratio
                        Rate(Mol,i,j) = Rate(Mol,i,j)*DD*Path(Mol,i)
                                                                ! k(E) in forward direction
                        IF ( Rate(Mol,i,j).GT.1.D-20 ) THEN
                           Rate(Mol,i,j) = LOG(Rate(Mol,i,j))
                                                        ! k(E) stored as log
                        ELSE
                           Rate(Mol,i,j) = LOG(1.D-20)  ! k(E) stored as log
                        ENDIF
 10                  CONTINUE
                  ELSE                  ! If grain or energy limit does not match
                     WRITE (KSTD,99002) TSname(Mol,i)
                     PAUSE
                     STOP
                  ENDIF
                  CLOSE (12)
 
               ENDIF
 20         CONTINUE
         ENDIF
 
 100  CONTINUE
 
      RETURN
 
99001 FORMAT (//,1x,f10.1,1x,I10,1x,f10.1,1x,I10,1x,f10.1/)
99002 FORMAT (/'Energy grain or energy limit does not match: ',
     &        A10/'****** Hit RETURN to terminate run *******')
 
      END
