**==stepper.spg  processed by SPAG 5.11R  at 20:12 on 26 Mar 2001
      SUBROUTINE STEPPER(Mol,E,T,NumbDens,IP,Delt)
 
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c MultiWell: a code for chemical kinetics calculations.
c Copyright (C) 2002 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful,
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c     01/02  v1.2.1  -New Feature: can optionally choose to apply centrifugal
c                     corrections for any choice of model. Thus can apply them
c                     even when using Inverse Laplace Transform form of k(E).
c                     NOTE: this new feature affects the data file format.
c     11/01  v1.1.4  -Bug Fix: previous version applied centrifugal correction 
c                      inconsistently when calculating Arrhenius parameters 
c                     (k(inf) was correct, however).
c     09/01  v1.1.2  -Revised centrigfugal corrections to k(E)'s.
c                     See Robinson & Holbrook (1972) eq. 4.30 and 4.31.
c
c***********************************************************************
c	Carries out Gillespie Exact Stochastic procedure for one step
c
c	Mol	= molecule index
c	E	= energy (relative to ZPE of Mol)
c	T	= translational temperature
c	NumbDens= number density of collider gas
c	IP	= index of selected process
c	Delt	= time step
c***********************************************************************
      IMPLICIT NONE
 
      INCLUDE 'declare1.inc'
 
      INTEGER Mol , i , IE , IP
 
      DOUBLE PRECISION Atot , RX , arg , E , X , Delt , Atemp , RAN1 , 
     &                 Y1 , Y2 , Y3 , Y , T , NumbDens , Aref , Fcoll
 
      EXTERNAL Fcoll
 
      SAVE 
 
      arg = Fcoll(Mol,E)*CollK(Mol)*NumbDens ! Inelastic collision frequency
      i = Nchan(Mol) + 1
      Rab(i) = arg
      Atot = Rab(Nchan(Mol)+1)          ! Collision frequency
 
      IF ( Nchan(Mol).GT.0 ) THEN       ! If reaction channels
         DO 50 i = 1 , Nchan(Mol)
            Rab(i) = 0.0D+00
            arg = E - Eor(Mol,i)         ! Active energy in TS to determine k(E); centrifugal correction
            IF ( arg.GE.0.0D+00 ) THEN
               CALL NTERP(arg,IE,X)
               Y1 = Rate(Mol,i,IE-1)
               Y2 = Rate(Mol,i,IE)
               Y3 = Rate(Mol,i,IE+1)
               CALL QUDINT(Y1,Y2,Y3,X,Y)
               Rab(i) = EXP(Y)           ! k(E) stored as log
               Atot = Atot + Rab(i)
            ENDIF
 50      CONTINUE
      ENDIF
 
      RX = RAN1(IDUM)
      Aref = RX*Atot
      Atemp = 0.0D+00
      i = 0
      DO WHILE ( (Atemp.LT.Aref) .AND. (i.LE.Nchan(Mol)) )
         i = i + 1
         IP = i
         Atemp = Atemp + Rab(i)
      ENDDO
 
      RX = RAN1(IDUM)
      Delt = -LOG(RX)/Atot              ! Determine time step
      IF ( RX.LE.1.00D-15 ) THEN        ! if random number too small
         RX = RAN1(IDUM)
         Delt = -LOG(RX)/Atot           ! Determine time step
      ENDIF
 
      RETURN
      END
