**==qhin.spg  processed by SPAG 5.11R  at 20:12 on 26 Mar 2001
      FUNCTION Qhin(T,B,V,n,nsig,C,SE,H,zpe)
 
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c Thermo: a code for thermochemical calculations.
c Copyright (C) 2003 John R. Barker
c
c John R. Barker
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c jrbarker@umich.edu
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful,
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the "ReadMe" file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c	Hindered Rotor partition function using "extended Troe" method for states
c
c	T	= temperature
c	B	= rotational constant (cm-1)
c	w	= vibrational frequency (cm-1)
c	V	= hindrance potential barrier (cm-1)
c	n	= periodicity of hindrance potential
c	nsig	= symmetry number of internal rotor
c	C	= constant p heat capacity (units of R)
c	SE	= entropy (units of R)
c	H	= [H(T)-H(0)]/RT
c       zpe     = zero point energy (cm-1)
c
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c    03/03  Enhancement: extended to include unsymmetrical hindered rotors
c    11/01  Bug fix: previously, an extra state was included in partition 
c                    function. This has very small quantitative effect.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

      IMPLICIT NONE
 
      DOUBLE PRECISION Qhin , T , B , w , V , C , SE , H
      DOUBLE PRECISION Q0 , Q1 , Q2 , r , zpe , Erot , Evib , Enet , 
     &                 Ered , Fac , Term , hor , S , Temp , EE
 
      INTEGER n , nsig , ns , nv , j

      PARAMETER (hor = 1.43843D+00)
 
      SAVE 
 
      Temp = T
      IF ( V .GT. 0.0 ) THEN
         w = n*SQRT(B*V)
         r = V/w
        ELSE
         w = 0.0
         r = 0.0
      ENDIF

      Q0 = 0.0d+00
      Q1 = 0.0D+00
      Q2 = 0.0D+00
      Fac = 1.0D+00
 
      IF (V/T .GT. 1.e-3) THEN             ! Hindered rotor
        ns = 1
        DO WHILE ( Fac .GE. 1.0D-10 )
           nv = INT((ns-1)/n)
           Evib = w*(nv+0.5) - w*(1+2.0*nv+2.0*nv*nv)/(16.0*r)
 
           j = ns/2 
           IF ( j.GT.r*n/2 .AND. r.GT.0.0 ) THEN
              Term = (r**4)*(n*n)*B/(8.0*((2.0*j/n)**2-1.0))
             ELSE
              Term = 0.0
           ENDIF
           Erot = B*j*j + V/2.0 + Term
 
           IF ( Erot .GT. 1.5*V ) THEN
              Enet = Erot
             ELSE
              S = 0.5*(1.0+TANH((Evib-V)/(0.2*V)))
              Enet = (1.0-S)*Evib + S*Erot
           ENDIF
  
           IF ( ns.EQ.1 ) zpe = Enet

           Ered = hor*(Enet-zpe)/Temp
           Fac = EXP(-Ered)
           Q0 = Q0 + Fac
           Q1 = Q1 + Ered*Fac
           Q2 = Q2 + Ered*Ered*Fac
 
           ns = ns + 1
        ENDDO
 
      ELSE                                   ! Free rotor
        zpe = 0.0
        j = 0
        Q0 = 1.0D+00
        DO WHILE ( Fac .GE. 1.0D-10 ) 
           j = j + 1
           EE = B*j*j*hor/Temp
           Fac = exp(-EE)
           Q0 = Q0 + 2.0*Fac
           Q1 = Q1 + 2.0*EE*Fac 
           Q2 = Q2 + 2.0*EE*EE*Fac 
        ENDDO

      ENDIF

      Q0 = Q0/nsig
      Q1 = Q1/nsig
      Q2 = Q2/nsig

c	Thermo formulae from Pitzer and Gwinn, J. Chem. Phys. 10, 428 (1942)
 
      Qhin = Q0
      C = Q2/Q0 - (Q1/Q0)**2
      H = Q1/Q0
      SE = (H+log(Q0))
 
      RETURN
 
      END
