
      PROGRAM THERMO
 
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
c
c Thermo: a code for thermochemical calculations.
c Copyright (C) 2003 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful,
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c
c	Equilibrium constants and thermodynamic parameters
c	based on molecular properties
c
c	Last modified: 
c       09/04 (JRB) Fixed bug that gave incorrect A,B in Kequil when MCC units
c       10/03 (JP) trimmed defined-length character strings with lenstr.
c       03/03 Incorporated unsymmetrical hindered internal rotation.
c       03/03 Refined output format
c       11/02 Fixed yet another bug related to vibrational degeneracies
c       3/02  Fixed bug that prevented correct treatment of vibrational
c             degeneracies.
c       2/02  Added particle in a Box
c       2/02  Output format changed in order to report zero point energies.
c       9/99 by J. R. Barker
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c	FORMAT FOR THERMO DATA FILE
c
c	LINE
c	1	Energy units Key-word	= 'CM-1', 'KCAL', or 'KJOU'
c		Std. State key-word	= 'ATM', 'BAR', 'MCC'
c					  (atmospheres, bars, molecules/cc)
c
c	2	Nt	= number of temperatures
c
c	3	List of temperatures
c
c	4	Ns	= number of species
c
c	REPEAT #5 and #6 Ns TIMES
c
c	5	REPROD	= key word:	'reac'	= reactant
c					'prod'	= product
c					'none'	= neither reactant nor product;
c					   not included in equilibrium constant
c		MOLNAME	= Name of chemical species (up to 10 characters)
c		DelH	= enthalpy of formation at 0 K
c		AMU	= molecular weight (g/mole)
c		Sym	= symmetry external symmetry number (INTEGER)
c		Sele	= electronic degeneracy (INTEGER)
c		Sopt	= number of optical isomers (INTEGER)
c		N	= number of vibrations and rotations to be read in
c               VHAR    = 'HAR': for vibrational frequencies input as harmonic freqs.
c                       = 'OBS': for vibrational frequencies input as 0-1 observed freqs.
c
c	REPEAT N TIMES
c
c	6	MODE, IDOF, WE, ANH, NG
c
c		MODE	= index number for degree of freedom
c		IDOF	= type of degree of freedom key word
c		= 'vib' (harmonic or Morse Potential vibration)
c			WE	= vib frequency (cm-1)
c			ANH	= vib anharmonicity (cm-1)
c			NG	= vib degeneracy
c		= 'box' (particle in a box vibration)
c			WE	= vib frequency (cm-1)
c			NG	= vib degeneracy
c		= 'rot' (classical rotation)
c			WE	= rot moment of inertia (amu*ang^2)
c			ANH	= rot symmetry (foldedness)
c			NG	= rot dimension
c		= 'hra' (1-D symmetrical hindered rotor)
c			WE	= reduced moment of inertia (amu*ang^2)
c			ANH	= vib frequency (cm-1)
c			NG	= barrier foldedness (POSITIVE if equal to internal 
c                                 rotor symmetry number, NEGATIVE if different from
c                                 symmetry number)
c                         [NSIG = internal rotor symmetry number, is read only if 
c                                 NG is NEGATIVE]
c		= 'hrb' (1-D symmetrical hindered rotor)
c			WE	= vib frequency (cm-1)
c			ANH	= barrier (cm-1)
c			NG	= barrier foldedness (POSITIVE if equal to internal 
c                                 rotor symmetry number, NEGATIVE if different from
c                                 symmetry number)
c                         [NSIG = internal rotor symmetry number, is read only if 
c                                 NG is NEGATIVE]
c		= 'hrc' (1-D symmetrical hindered rotor)
c			WE	= reduced moment of inertia (amu*ang^2)
c			ANH	= barrier (cm-1)
c			NG	= barrier foldedness (POSITIVE if equal to internal 
c                                 rotor symmetry number, NEGATIVE if different from
c                                 symmetry number)
c                         [NSIG = internal rotor symmetry number, is read only if 
c                                 NG is NEGATIVE]
c
c	7	BLANK LINE
c
      IMPLICIT NONE
 
      CHARACTER AVERSION*6, ADATE*12
      PARAMETER ( AVERSION='1.4.1 ', ADATE='SEP 2004  ' )

      INTEGER Nmax , lenstr
 
      PARAMETER (Nmax=6)        ! maximum number of species
 
      CHARACTER IDOF*3 , VIB*3 , ROT*3 , QRO*3 , REPROD*4 , REAC*4 , 
     &          PROD*4 , MOLNAME*10 , CAP*27 , Eunits*4 , Sunits*4 , 
     &          UNITS*12 , HIN*3 , HRA*3 , HRB*3 , HRC*3 , VHAR*3 ,
     &          OBS*3 , HAR*3 , BOX*3
 
      INTEGER N(Nmax) , Ns , NG , MODE , i , Sym , Sele , Sopt , Nreac , 
     &        Nprod , II , j , Nt , k , ss , dim , NSIG
 
      DOUBLE PRECISION WE , ANH , AMU , T , DelH , Cp , Sfac , ff , 
     &                 Hvib , Hrot , Hroq , Svib , Srot , Sroq , S , H , 
     &                 Rgas , B , AMOM , W , VV , Qhin , Hhin , Chin , 
     &                 Shin , Croq , zap , zzpe, DDelH, DG
 
      DIMENSION IDOF(Nmax,150) , WE(Nmax,150) , ANH(Nmax,150) , 
     &          NG(Nmax,150) , MODE(Nmax,150) , REPROD(Nmax) , 
     &          NSIG(Nmax,150)
 
      DIMENSION AMOM(Nmax,150) , W(Nmax,150) , VV(Nmax,150) , 
     &          B(Nmax,150)
 
      DIMENSION AMU(Nmax) , MOLNAME(Nmax) , Sym(Nmax) , Sele(Nmax) , 
     &          Sopt(Nmax) , DelH(Nmax) , H(Nmax) , S(Nmax) , T(100) , 
     &          Cp(Nmax) , zzpe(Nmax)
 
      PARAMETER (VIB='vib',ROT='rot',QRO='qro',REAC='reac',PROD='prod',
     &           CAP='Entropy  Cp  [H(T)-H(0)] ',HIN='hin',HRA='hra',
     &           HRB='hrb',HRC='hrc',OBS='OBS',HAR='HAR',BOX='box')
 
      DOUBLE PRECISION Qvib , Qbox , Qrot , q , Qreac , Qprod , Kequil , 
     &                 Hdiff , Cvib , Crot , qq , AA , BB , DSR , DHR , 
     &                 Qroq , WOBS , DCp , Dzpe, Hpib, Cpib, Spib
 
      SAVE 
 
cMAC      OPEN(UNIT=4,STATUS='OLD',FILE='')					! General Data file
cMAC      OPEN(UNIT=3,STATUS='UNKNOWN',FILE='thermo.out',CREATOR='TBB6')	! Full output
      OPEN (UNIT=4,STATUS='OLD',FILE='thermo.dat')                      ! General Data file
      OPEN (UNIT=3,STATUS='UNKNOWN',FILE='thermo.out')          ! Full output
 
      WRITE (3,99002) AVERSION , ADATE
      READ (4,*) Eunits , Sunits
 
      IF ( Eunits.EQ.'KCAL' .OR. Eunits.EQ.'kcal' ) THEN
         Rgas = 1.986503D+00
      ELSEIF ( Eunits.EQ.'KJOU' .OR. Eunits.EQ.'kjou' ) THEN
         Rgas = 8.3145472D+00
      ELSEIF ( Eunits.EQ.'CM-1' .OR. Eunits.EQ.'cm-1' ) THEN
         Rgas = 0.6950356D+00
      ENDIF
 
      IF ( Sunits.EQ.'ATM' .OR. Sunits.EQ.'atm' ) THEN
         UNITS = 'atmospheres'
      ELSEIF ( Sunits.EQ.'BAR' .OR. Sunits.EQ.'bar' ) THEN
         UNITS = 'bars'
      ELSEIF ( Sunits.EQ.'MCC' .OR. Sunits.EQ.'mcc' ) THEN
         UNITS = 'molecules/cc'
      ENDIF
 
      READ (4,*) Nt
c
c	Number of temperatures (K)
c
      READ (4,*) (T(j),j=1,Nt)  ! Read list of temperatures
 
      Hdiff = 0.0
      Nreac = 0
      Nprod = 0
 
      READ (4,*) Ns
c
c	Number of species
c
      DO 100 i = 1 , Ns
         READ (4,*) REPROD(i) , MOLNAME(i) , DelH(i) , AMU(i) , Sym(i) , 
     &              Sele(i) , Sopt(i) , N(i) , VHAR
c
c	reac/prod, name, Enthalpy(0 K), molecular weight (amu),
c		symmetry,electronic degeneracy,optical isomers,
c		internal degrees of freedom (rots + vibs) to be read,
c               and whether vib. freqs. are harmonic, or observed 0-1 transitions
c
         IF ( REPROD(i).EQ.REAC ) THEN
            Nreac = Nreac + 1
            Hdiff = Hdiff - 1000.*DelH(i)       ! Hdiff in cal/mole or J/mole
         ELSEIF ( REPROD(i).EQ.PROD ) THEN
            Nprod = Nprod + 1
            Hdiff = Hdiff + 1000.*DelH(i)       ! Hdiff in cal/mole or J/mole
         ENDIF
         WRITE (3,99014) MOLNAME(i)(1:lenstr(MOLNAME(i))) , N(i)
 
         zzpe(i) = 0.0
         IF ( N(i).GT.0 ) THEN
            DO 20 II = 1 , N(i)
               READ (4,*) MODE(i,II) , IDOF(i,II) , WE(i,II) , ANH(i,II)
     &                    , NG(i,II)
               IF ( IDOF(i,II).EQ.VIB ) THEN                    ! VIBRATION
                  W(i,II) = WE(i,II)
                  IF ( VHAR .EQ. HAR ) THEN
                   WOBS = WE(i,II)+2.*ANH(i,II)           ! WOBS = observed freq
                  ELSEIF ( VHAR .EQ. OBS ) THEN
                   WOBS = WE(i,II)
                   WE(i,II)= WE(i,II)-2.*ANH(i,II)        ! Convert WE to harmonic frequency
                  ENDIF
                  qq=Qvib(10.d+00,WE(i,II),ANH(i,II),NG(i,II),Cvib,Svib,
     &                    Hvib,zap)
                  zzpe(i) = zzpe(i) + zap
                  WRITE (3,99010) MODE(i,II) , WOBS , W(i,II) , 
     &                      ANH(i,II) , zap , NG(i,II)
               ELSEIF ( IDOF(i,II).EQ.BOX ) THEN                    ! PARTICLE IN A BOX 
                  W(i,II) = WE(i,II)
                  IF ( VHAR .EQ. HAR ) THEN
                   WOBS = 3.0d+00*WE(i,II)                ! WOBS = observed freq (note that ANH is a placeholder: not used)
                  ELSEIF ( VHAR .EQ. OBS ) THEN
                   WOBS = WE(i,II)
                   WE(i,II)= WE(i,II)/3.0d+00             ! Convert WE to harmonic frequency
                  ENDIF
                  zap = W(i,II)
                  zzpe(i) = zzpe(i) + zap
                  WRITE (3,99110) MODE(i,II) , WOBS , W(i,II) , 
     &                      zap , NG(i,II)
               ELSEIF ( IDOF(i,II).EQ.ROT ) THEN                ! CLASSICAL ROTOR
                  AMOM(i,II) = WE(i,II)
                  BB = 16.85763D+00/AMOM(i,II)                  ! rotational constant (cm-1)
                  WRITE (3,99011) MODE(i,II) , WE(i,II) , ANH(i,II) , 
     &                            NG(i,II) , BB
               ELSEIF ( IDOF(i,II).EQ.QRO ) THEN                ! QUANTUM ROTOR
                  AMOM(i,II) = WE(i,II)
                  BB = 16.85763D+00/AMOM(i,II)                  ! rotational constant (cm-1)
                  WRITE (3,99012) MODE(i,II) , WE(i,II) , ANH(i,II) , 
     &                            NG(i,II) , BB
               ELSEIF ( IDOF(i,II).EQ.HRA ) THEN                ! HINDERED ROTOR (modified Troe method) INPUT MOMENT & VIB FREQ
                  IF ( NG(i,II) .LT. 0 ) THEN
                      READ(4,*) NSIG(i,II)
                      NG(i,II) = -NG(i,II)
                    ELSE
                      NSIG(i,II) = NG(i,II)
                  ENDIF
                  W(i,II) = WE(i,II)            ! moment of inertia
                  AMOM(i,II) = ANH(i,II)                ! small vibration frequency
                  B(i,II) = 16.85763D+00/AMOM(i,II)     ! rotational constant (cm-1)
                  VV(i,II) = ((W(i,II)/NG(i,II))**2)/B(i,II)
                                                        ! hindrance barrier (cm-1)
                  qq=Qhin(10.d+00,B(i,II),VV(i,II),NG(i,II),NSIG(i,II),
     &                    Chin,Shin,Hhin,zap)
                  zzpe(i) = zzpe(i) + zap
                  WRITE (3,99001) MODE(i,II) , W(i,II) , AMOM(i,II) , 
     &                NG(i,II) , NSIG(i,II) , B(i,II) , zap , VV(i,II)
                  IDOF(i,II) = HIN
               ELSEIF ( IDOF(i,II).EQ.HRB ) THEN                ! HINDERED ROTOR (modified Troe method) INPUT VIB FREQ & BARRIER
                  IF ( NG(i,II) .LT. 0 ) THEN
                      READ(4,*) NSIG(i,II)
                      NG(i,II) = -NG(i,II)
                    ELSE
                      NSIG(i,II) = NG(i,II)
                  ENDIF
                  W(i,II) = WE(i,II)            ! small vibration frequency
                  VV(i,II) = ANH(i,II)                  ! hindrance barrier (cm-1)
                  IF (VV(i,II) .LT. 1.0d-05) STOP
     &            'Rotation barrier too small. Hit RETURN to terminate'
                  B(i,II) = ((W(i,II)/NG(i,II))**2)/VV(i,II)
                                                        ! rotational constant (cm-1)
                  AMOM(i,II) = 16.85763D+00/B(i,II)     ! rotational constant (cm-1)
                  qq=Qhin(10.d+00,B(i,II),VV(i,II),NG(i,II),NSIG(i,II),
     &                    Chin,Shin,Hhin,zap)
                  zzpe(i) = zzpe(i) + zap
                  WRITE (3,99001) MODE(i,II) , W(i,II) , AMOM(i,II) , 
     &                NG(i,II) , NSIG(i,II) , B(i,II) , zap , VV(i,II)
                  IDOF(i,II) = HIN
               ELSEIF ( IDOF(i,II).EQ.HRC ) THEN                ! HINDERED ROTOR (modified Troe method) INPUT MOMENT & BARRIER
                  IF ( NG(i,II) .LT. 0) THEN
                      READ(4,*) NSIG(i,II)
                      NG(i,II) = -NG(i,II)
                    ELSE
                      NSIG(i,II) = NG(i,II)
                  ENDIF
                  AMOM(i,II) = WE(i,II)                 ! moment of inertia
                  B(i,II) = 16.85763D+00/AMOM(i,II)     ! rotational constant (cm-1)
                  VV(i,II) = ANH(i,II)                  ! hindrance barrier (cm-1)
                  W(i,II) = NG(i,II)*SQRT(B(i,II)*VV(i,II))
                                                        ! small vibration frequency
                  qq=Qhin(10.d+00,B(i,II),VV(i,II),NG(i,II),NSIG(i,II),
     &                    Chin,Shin,Hhin,zap)
                  zzpe(i) = zzpe(i) + zap
                  WRITE (3,99001) MODE(i,II) , W(i,II) , AMOM(i,II) , 
     &                NG(i,II) , NSIG(i,II) , B(i,II) , zap , VV(i,II)
                                                ! Hindered rotor (modified Troe method)
                  IDOF(i,II) = HIN
               ENDIF
 20         CONTINUE
         ENDIF
 
 100  CONTINUE
 
         DDelH = 0.0d+00
         Dzpe = 0.0d+00
      WRITE (3,99016)
      DO 200 i = 1 , Ns
            IF ( REPROD(i).EQ.REAC ) THEN
               DDelH = DDelH - DelH(i)          ! Delta H(0) for reaction
               Dzpe = Dzpe - zzpe(i)            ! Delta zpe for reaction
            ELSEIF ( REPROD(i).EQ.PROD ) THEN
               DDelH = DDelH + DelH(i)          ! Delta H(0) for reaction
               Dzpe = Dzpe + zzpe(i)            ! Delta zpe for reaction
            ENDIF
         WRITE (3,99017) REPROD(i) , MOLNAME(i) 
     & , AMU(i) , DelH(i) , zzpe(i) , Sym(i) , Sele(i) , Sopt(i)
 200  CONTINUE
         WRITE (3,99021)
         WRITE (3,99020) DDelH, Dzpe
 
c
c	Thermodynamic functions at T and T*del
c
      IF ( Eunits.EQ.'KCAL' ) THEN
         WRITE (3,99004) UNITS ,
     &   (MOLNAME(i)(1:lenstr(MOLNAME(i))),i=1,Ns)
      ELSEIF ( Eunits.EQ.'KJOU' ) THEN
         WRITE (3,99005) UNITS ,
     &   (MOLNAME(i)(1:lenstr(MOLNAME(i))),i=1,Ns)
      ENDIF
      WRITE (3,99006) (REPROD(i),i=1,Ns)
      WRITE (3,99003) (CAP,i=1,Ns)
 
      DO 400 k = 1 , Nt
         Qreac = 1.0
         Qprod = 1.0
         DO 250 i = 1 , Ns
 
            IF ( Sunits.EQ.'ATM' ) THEN ! first part of translational part. fxn.
               q = (DBLE(Sele(i)*Sopt(i))/DBLE(Sym(i)))*0.02560*T(k)    ! (std. state= 1 atm)
            ELSEIF ( Sunits.EQ.'BAR' ) THEN
               q = (DBLE(Sele(i)*Sopt(i))/DBLE(Sym(i)))*0.02594*T(k)    ! (std. state= 1 bar)
            ELSEIF ( Sunits.EQ.'MCC' ) THEN
               q = (DBLE(Sele(i)*Sopt(i))/DBLE(Sym(i)))*(1.87915E+20)   ! (std. state= 1 molecule/cc)
            ENDIF
            q = q*(AMU(i)*T(k))**1.5    ! second part of translational part. fxn.
            ff = 3.6648556 - 1.5*log(AMU(i)) - 2.5*log(T(k))
            H(i) = 2.5*Rgas*T(k)        ! H(T)-H(0)
            Cp(i) = 2.5*Rgas
            S(i) = Rgas*((2.5-ff)+log(DBLE(Sele(i)*Sopt(i))/DBLE(Sym(i))
     &             ))
            IF ( N(i).NE.0 ) THEN                                   ! for non-monatomic species
               DO 210 j = 1 , N(i)
                  IF ( IDOF(i,j).EQ.VIB ) THEN  ! VIBRATION
                     qq = Qvib(T(k),WE(i,j),ANH(i,j),NG(i,j),Cvib,Svib,
     &                    Hvib,zap)
                     q = q*qq
                     Cp(i) = Cp(i) + Cvib*Rgas
                     H(i) = H(i) + Rgas*Hvib*T(k)
                     S(i) = S(i) + Rgas*Svib
                  ELSEIF ( IDOF(i,j).EQ.BOX ) THEN  ! PARTICLE IN A BOX
                     qq = Qbox(T(k),WE(i,j),NG(i,j),Cpib,Spib,Hpib,zap)
                     q = q*qq
                     Cp(i) = Cp(i) + Cpib*Rgas
                     H(i) = H(i) + Rgas*Hpib*T(k)
                     S(i) = S(i) + Rgas*Spib
                  ELSEIF ( IDOF(i,j).EQ.ROT ) THEN
                                                ! CLASSICAL ROTOR
                     BB = 16.85763D+00/WE(i,j)  ! rotational constant (cm-1)
                     dim = NG(i,j)
                                ! rotor dimension
                     ss = INT(ANH(i,j))
                                ! rotor symmetry number (not included in over-all symmetry)
                     qq = Qrot(T(k),BB,dim,ss,Crot,Srot,Hrot)
                     q = q*qq
                     Cp(i) = Cp(i) + Crot*Rgas
                     H(i) = H(i) + Hrot*Rgas*T(k)
                     S(i) = S(i) + Srot*Rgas
                  ELSEIF ( IDOF(i,j).EQ.QRO ) THEN
                                                ! QUANTUM ROTOR
                     BB = 16.85763D+00/WE(i,j)  ! rotational constant (cm-1)
                     dim = NG(i,j)
                                ! rotor dimension
                     ss = INT(ANH(i,j))
                                ! rotor symmetry number (not included in over-all symmetry)
                     qq = Qroq(T(k),BB,dim,ss,Croq,Sroq,Hroq)
                     q = q*qq
                     Cp(i) = Cp(i) + Croq*Rgas
                     H(i) = H(i) + Hroq*Rgas*T(k)
                     S(i) = S(i) + Sroq*Rgas
                  ELSEIF ( IDOF(i,j).EQ.HIN ) THEN
                                                ! HINDERED ROTOR
                     qq = Qhin(T(k),B(i,j),VV(i,j),NG(i,j),NSIG(i,j),
     &                   Chin,Shin,Hhin,zap)
                     q = q*qq
                     Cp(i) = Cp(i) + Chin*Rgas
                     H(i) = H(i) + Hhin*Rgas*T(k)
                     S(i) = S(i) + Shin*Rgas
                  ENDIF
 210           CONTINUE
            ENDIF
            IF ( REPROD(i).EQ.REAC ) THEN
               Qreac = Qreac*q
            ELSEIF ( REPROD(i).EQ.PROD ) THEN
               Qprod = Qprod*q
            ENDIF
 250     CONTINUE
 
         IF ( Sunits.EQ.'ATM' ) THEN
            Sfac = 0.0
         ELSEIF ( Sunits.EQ.'BAR' ) THEN
            Sfac = Rgas*log(1.01325)
         ELSEIF ( Sunits.EQ.'MCC' ) THEN
            Sfac = Rgas*log(1.87915E+20/(0.02594*T(k)))
         ENDIF
 
         DSR = 0.0D+00
         DHR = Hdiff
         DCp = 0.0d+00
         DO 300 i = 1 , Ns
            IF ( REPROD(i).EQ.REAC ) THEN
               DSR = DSR - (Sfac+S(i))          ! Delta S for reaction
               DHR = DHR - H(i)                 ! Delta H for reaction
               DCp = DCp - Cp(i)                ! Delta Cp for reaction
            ELSEIF ( REPROD(i).EQ.PROD ) THEN
               DSR = DSR + (Sfac+S(i))          ! Delta S for reaction
               DHR = DHR + H(i)                 ! Delta H for reaction
               DCp = DCp + Cp(i)                ! Delta Cp for reaction
            ENDIF
 300     CONTINUE
 
         DG = (DSR - DHR/T(k))/Rgas
         Kequil = exp(DG)
         IF (Sunits .NE. 'MCC') THEN
           AA = exp(DSR/Rgas)
           BB = -DHR/Rgas
          ELSE
           BB = -DHR/Rgas + T(k)
           AA = Kequil*exp(-BB/T(k))
         ENDIF
 
         WRITE (3,99007) T(k) , Kequil , AA , BB , DSR , DHR/1000. , 
     &              DCp , (Sfac+S(i),Cp(i),H(i)/1000.,i=1,Ns)
 400  CONTINUE
 
99001 FORMAT (I5,2X,'Hind.Rot',2x,'Freq(har)=',F8.2,2x,'Mom=',F8.3,2x,
     &       'fold=',I2,2x,'symm=',I2,2x,'B=',F8.4,' cm-1',2x,
     &        'zpe(cm-1)=',F8.1,2x,'Uo=',F7.1,' cm-1')
99002 FORMAT ('Thermo-',A6,5X,A12,/
     &        '   John R. Barker'/
     &        '   jrbarker@umich.edu'/
     &        '   University of Michigan'//)
99003 FORMAT (8x,'T(K)',6x,'Kequil',4x,'A(T)',7x,'B(T)',4x,'DelS(rxn)',
     &        1x,'DelH(rxn)',1x,'DelCp(rxn)',5x,6(A27,1x))
99004 FORMAT (//'THERMODYNAMIC QUANTITIES',10x,'Std. State = ',A12/,3x,
     &        'Entropy & Cp units: cal/K/mole'/3x,
     &        'DelS         units: cal/K/mole'/3x,
     &        '[H(T)-H(0)]  units: kcal/mole'/3x,
     &        'DelH         units: kcal/mole'//80x,6(7x,A10,11x))
99005 FORMAT (//'THERMODYNAMIC QUANTITIES',10x,'Std. State = ',A12/,3x,
     &        'Entropy & Cp units: J/K/mole'/3x,
     &        'DelS         units: J/K/mole'/3x,
     &        '[H(T)-H(0)]  units: kJ/mole'/3x,
     &        'DelH         units: kJ/mole'//74x,6(7x,A10,11x))
99006 FORMAT (25x,'Kequil = A*exp(B/T)',36x,6(7x,A4,17x))
c99007 FORMAT (2x,f10.1,2(2x,1pe10.3),2x,0pf7.0,1x,0pf9.3,1x,0pf8.2,
c     &        1x,0pf10.4,3x,6(2x,0pf8.2,1x,f8.2,1x,f8.2))
99007 FORMAT (2x,f10.1,2(2x,1pe10.3),2x,0pf7.0,1x,0pf9.1,1x,0pf8.1, 
     &        1x,0pf10.1,3x,6(2x,0pf8.2,1x,f8.2,1x,f8.2)) 
99008 FORMAT (/)
99009 FORMAT (1x,f10.1,1x,I10,1x,f10.1,1x,I10,1x,f10.1)
99010  FORMAT (I5,2X,'Vibrator',2x,'Freq(obs)=',F8.2,2x,
     &        'Freq(har)=',F8.2,2x,'Anh(cm-1)=',F8.2,2X,
     &        'zpe(cm-1) =',F8.1,2x,'   g =',I2)
99110  FORMAT (I5,2X,'P-in-Box',2x,'Freq(obs)=',F8.2,2x,
     &        'Freq(har)=',F8.2,2x,
     &        'zpe(cm-1) =',F8.1,2x,'   g =',I2)
99011 FORMAT (I5,2X,'Clas.Rot',2x,'Moment   =',F8.2,2x,'Symm =',F4.0,2x,
     &        ' dim =',I2,2x,'B =',F8.4,' cm-1')
99012 FORMAT (I5,2X,'Quan.Rot',2x,'Moment   =',F8.2,2x,'Symm =',F4.0,2x,
     &        ' dim =',I2,2x,'B =',F8.4,' cm-1')
99013 FORMAT (/'  No.  Freq(cm-1)  ANH(cm-1)      Degeneracy'/)
99014 FORMAT (//A10/I3,1x,'degrees of freedom'/)
99015 FORMAT (F10.1,4x,3(1pe10.3,4x),6(1pe10.3,1x))
99016 FORMAT (//'INPUT DATA: REACTANTS & PRODUCTS'//
     & ,' TYPE  NAME        Mol.Wt.   Enthalpy(O K)  ZPE(cm-1) Symmetry'
     & ,'  Elec.deg.  opt.isomers')
99017 FORMAT (1x,A4,2x,A10,2(2x,F7.2),8x,F7.1,3I10)
99018 FORMAT (A100)
99019 FORMAT (1x,A10,2(5x,F10.2))
99020 FORMAT (14X,'NET',8x,F10.2,5x,F10.1)
99021 FORMAT (27x,'--------',5x,'----------')
      END
